/*
*******************************************************************************
*   Copyright (C) 2002-2008, International Business Machines
*   Corporation and others.  All Rights Reserved.
*******************************************************************************
*
*   file name:  urename.h
*   encoding:   US-ASCII
*   tab size:   8 (not used)
*   indentation:4
*
*   Created by: Perl script written by Vladimir Weinstein
*
*  Contains data for renaming ICU exports.
*  Gets included by umachine.h
*
*  THIS FILE IS MACHINE-GENERATED, DON'T PLAY WITH IT IF YOU DON'T KNOW WHAT
*  YOU ARE DOING, OTHERWISE VERY BAD THINGS WILL HAPPEN!
*/

#ifndef URENAME_H
#define URENAME_H

/* Uncomment the following line to disable renaming on platforms
   that do not use Autoconf. */
/* #define U_DISABLE_RENAMING 1 */

#if !U_DISABLE_RENAMING

/* C exports renaming data */

#define T_CString_int64ToString T_CString_int64ToString_4_0
#define T_CString_integerToString T_CString_integerToString_4_0
#define T_CString_stricmp T_CString_stricmp_4_0
#define T_CString_stringToInteger T_CString_stringToInteger_4_0
#define T_CString_strnicmp T_CString_strnicmp_4_0
#define T_CString_toLowerCase T_CString_toLowerCase_4_0
#define T_CString_toUpperCase T_CString_toUpperCase_4_0
#define UCNV_FROM_U_CALLBACK_ESCAPE UCNV_FROM_U_CALLBACK_ESCAPE_4_0
#define UCNV_FROM_U_CALLBACK_SKIP UCNV_FROM_U_CALLBACK_SKIP_4_0
#define UCNV_FROM_U_CALLBACK_STOP UCNV_FROM_U_CALLBACK_STOP_4_0
#define UCNV_FROM_U_CALLBACK_SUBSTITUTE UCNV_FROM_U_CALLBACK_SUBSTITUTE_4_0
#define UCNV_TO_U_CALLBACK_ESCAPE UCNV_TO_U_CALLBACK_ESCAPE_4_0
#define UCNV_TO_U_CALLBACK_SKIP UCNV_TO_U_CALLBACK_SKIP_4_0
#define UCNV_TO_U_CALLBACK_STOP UCNV_TO_U_CALLBACK_STOP_4_0
#define UCNV_TO_U_CALLBACK_SUBSTITUTE UCNV_TO_U_CALLBACK_SUBSTITUTE_4_0
#define UDataMemory_createNewInstance UDataMemory_createNewInstance_4_0
#define UDataMemory_init UDataMemory_init_4_0
#define UDataMemory_isLoaded UDataMemory_isLoaded_4_0
#define UDataMemory_normalizeDataPointer UDataMemory_normalizeDataPointer_4_0
#define UDataMemory_setData UDataMemory_setData_4_0
#define UDatamemory_assign UDatamemory_assign_4_0
#define _ASCIIData _ASCIIData_4_0
#define _Bocu1Data _Bocu1Data_4_0
#define _CESU8Data _CESU8Data_4_0
#define _HZData _HZData_4_0
#define _IMAPData _IMAPData_4_0
#define _ISCIIData _ISCIIData_4_0
#define _ISO2022Data _ISO2022Data_4_0
#define _LMBCSData1 _LMBCSData1_4_0
#define _LMBCSData11 _LMBCSData11_4_0
#define _LMBCSData16 _LMBCSData16_4_0
#define _LMBCSData17 _LMBCSData17_4_0
#define _LMBCSData18 _LMBCSData18_4_0
#define _LMBCSData19 _LMBCSData19_4_0
#define _LMBCSData2 _LMBCSData2_4_0
#define _LMBCSData3 _LMBCSData3_4_0
#define _LMBCSData4 _LMBCSData4_4_0
#define _LMBCSData5 _LMBCSData5_4_0
#define _LMBCSData6 _LMBCSData6_4_0
#define _LMBCSData8 _LMBCSData8_4_0
#define _Latin1Data _Latin1Data_4_0
#define _MBCSData _MBCSData_4_0
#define _SCSUData _SCSUData_4_0
#define _UTF16BEData _UTF16BEData_4_0
#define _UTF16Data _UTF16Data_4_0
#define _UTF16LEData _UTF16LEData_4_0
#define _UTF32BEData _UTF32BEData_4_0
#define _UTF32Data _UTF32Data_4_0
#define _UTF32LEData _UTF32LEData_4_0
#define _UTF7Data _UTF7Data_4_0
#define _UTF8Data _UTF8Data_4_0
#define cmemory_cleanup cmemory_cleanup_4_0
#define cmemory_inUse cmemory_inUse_4_0
#define le_close le_close_4_0
#define le_create le_create_4_0
#define le_getCharIndices le_getCharIndices_4_0
#define le_getCharIndicesWithBase le_getCharIndicesWithBase_4_0
#define le_getGlyphCount le_getGlyphCount_4_0
#define le_getGlyphPosition le_getGlyphPosition_4_0
#define le_getGlyphPositions le_getGlyphPositions_4_0
#define le_getGlyphs le_getGlyphs_4_0
#define le_layoutChars le_layoutChars_4_0
#define le_reset le_reset_4_0
#define locale_getKeywords locale_getKeywords_4_0
#define locale_get_default locale_get_default_4_0
#define locale_set_default locale_set_default_4_0
#define pl_addFontRun pl_addFontRun_4_0
#define pl_addLocaleRun pl_addLocaleRun_4_0
#define pl_addValueRun pl_addValueRun_4_0
#define pl_close pl_close_4_0
#define pl_closeFontRuns pl_closeFontRuns_4_0
#define pl_closeLine pl_closeLine_4_0
#define pl_closeLocaleRuns pl_closeLocaleRuns_4_0
#define pl_closeValueRuns pl_closeValueRuns_4_0
#define pl_countLineRuns pl_countLineRuns_4_0
#define pl_create pl_create_4_0
#define pl_getAscent pl_getAscent_4_0
#define pl_getDescent pl_getDescent_4_0
#define pl_getFontRunCount pl_getFontRunCount_4_0
#define pl_getFontRunFont pl_getFontRunFont_4_0
#define pl_getFontRunLastLimit pl_getFontRunLastLimit_4_0
#define pl_getFontRunLimit pl_getFontRunLimit_4_0
#define pl_getLeading pl_getLeading_4_0
#define pl_getLineAscent pl_getLineAscent_4_0
#define pl_getLineDescent pl_getLineDescent_4_0
#define pl_getLineLeading pl_getLineLeading_4_0
#define pl_getLineVisualRun pl_getLineVisualRun_4_0
#define pl_getLineWidth pl_getLineWidth_4_0
#define pl_getLocaleRunCount pl_getLocaleRunCount_4_0
#define pl_getLocaleRunLastLimit pl_getLocaleRunLastLimit_4_0
#define pl_getLocaleRunLimit pl_getLocaleRunLimit_4_0
#define pl_getLocaleRunLocale pl_getLocaleRunLocale_4_0
#define pl_getParagraphLevel pl_getParagraphLevel_4_0
#define pl_getTextDirection pl_getTextDirection_4_0
#define pl_getValueRunCount pl_getValueRunCount_4_0
#define pl_getValueRunLastLimit pl_getValueRunLastLimit_4_0
#define pl_getValueRunLimit pl_getValueRunLimit_4_0
#define pl_getValueRunValue pl_getValueRunValue_4_0
#define pl_getVisualRunAscent pl_getVisualRunAscent_4_0
#define pl_getVisualRunDescent pl_getVisualRunDescent_4_0
#define pl_getVisualRunDirection pl_getVisualRunDirection_4_0
#define pl_getVisualRunFont pl_getVisualRunFont_4_0
#define pl_getVisualRunGlyphCount pl_getVisualRunGlyphCount_4_0
#define pl_getVisualRunGlyphToCharMap pl_getVisualRunGlyphToCharMap_4_0
#define pl_getVisualRunGlyphs pl_getVisualRunGlyphs_4_0
#define pl_getVisualRunLeading pl_getVisualRunLeading_4_0
#define pl_getVisualRunPositions pl_getVisualRunPositions_4_0
#define pl_isComplex pl_isComplex_4_0
#define pl_nextLine pl_nextLine_4_0
#define pl_openEmptyFontRuns pl_openEmptyFontRuns_4_0
#define pl_openEmptyLocaleRuns pl_openEmptyLocaleRuns_4_0
#define pl_openEmptyValueRuns pl_openEmptyValueRuns_4_0
#define pl_openFontRuns pl_openFontRuns_4_0
#define pl_openLocaleRuns pl_openLocaleRuns_4_0
#define pl_openValueRuns pl_openValueRuns_4_0
#define pl_reflow pl_reflow_4_0
#define pl_resetFontRuns pl_resetFontRuns_4_0
#define pl_resetLocaleRuns pl_resetLocaleRuns_4_0
#define pl_resetValueRuns pl_resetValueRuns_4_0
#define res_countArrayItems res_countArrayItems_4_0
#define res_findResource res_findResource_4_0
#define res_getAlias res_getAlias_4_0
#define res_getArrayItem res_getArrayItem_4_0
#define res_getBinary res_getBinary_4_0
#define res_getIntVector res_getIntVector_4_0
#define res_getResource res_getResource_4_0
#define res_getString res_getString_4_0
#define res_getTableItemByIndex res_getTableItemByIndex_4_0
#define res_getTableItemByKey res_getTableItemByKey_4_0
#define res_load res_load_4_0
#define res_unload res_unload_4_0
#define transliterator_cleanup transliterator_cleanup_4_0
#define triedict_swap triedict_swap_4_0
#define u_UCharsToChars u_UCharsToChars_4_0
#define u_austrcpy u_austrcpy_4_0
#define u_austrncpy u_austrncpy_4_0
#define u_catclose u_catclose_4_0
#define u_catgets u_catgets_4_0
#define u_catopen u_catopen_4_0
#define u_charAge u_charAge_4_0
#define u_charDigitValue u_charDigitValue_4_0
#define u_charDirection u_charDirection_4_0
#define u_charFromName u_charFromName_4_0
#define u_charMirror u_charMirror_4_0
#define u_charName u_charName_4_0
#define u_charType u_charType_4_0
#define u_charsToUChars u_charsToUChars_4_0
#define u_cleanup u_cleanup_4_0
#define u_countChar32 u_countChar32_4_0
#define u_digit u_digit_4_0
#define u_enumCharNames u_enumCharNames_4_0
#define u_enumCharTypes u_enumCharTypes_4_0
#define u_errorName u_errorName_4_0
#define u_fclose u_fclose_4_0
#define u_feof u_feof_4_0
#define u_fflush u_fflush_4_0
#define u_fgetConverter u_fgetConverter_4_0
#define u_fgetc u_fgetc_4_0
#define u_fgetcodepage u_fgetcodepage_4_0
#define u_fgetcx u_fgetcx_4_0
#define u_fgetfile u_fgetfile_4_0
#define u_fgetlocale u_fgetlocale_4_0
#define u_fgets u_fgets_4_0
#define u_file_read u_file_read_4_0
#define u_file_write u_file_write_4_0
#define u_file_write_flush u_file_write_flush_4_0
#define u_finit u_finit_4_0
#define u_foldCase u_foldCase_4_0
#define u_fopen u_fopen_4_0
#define u_forDigit u_forDigit_4_0
#define u_formatMessage u_formatMessage_4_0
#define u_formatMessageWithError u_formatMessageWithError_4_0
#define u_fprintf u_fprintf_4_0
#define u_fprintf_u u_fprintf_u_4_0
#define u_fputc u_fputc_4_0
#define u_fputs u_fputs_4_0
#define u_frewind u_frewind_4_0
#define u_fscanf u_fscanf_4_0
#define u_fscanf_u u_fscanf_u_4_0
#define u_fsetcodepage u_fsetcodepage_4_0
#define u_fsetlocale u_fsetlocale_4_0
#define u_fsettransliterator u_fsettransliterator_4_0
#define u_fstropen u_fstropen_4_0
#define u_fungetc u_fungetc_4_0
#define u_getCombiningClass u_getCombiningClass_4_0
#define u_getDataDirectory u_getDataDirectory_4_0
#define u_getDefaultConverter u_getDefaultConverter_4_0
#define u_getFC_NFKC_Closure u_getFC_NFKC_Closure_4_0
#define u_getISOComment u_getISOComment_4_0
#define u_getIntPropertyMaxValue u_getIntPropertyMaxValue_4_0
#define u_getIntPropertyMinValue u_getIntPropertyMinValue_4_0
#define u_getIntPropertyValue u_getIntPropertyValue_4_0
#define u_getNumericValue u_getNumericValue_4_0
#define u_getPropertyEnum u_getPropertyEnum_4_0
#define u_getPropertyName u_getPropertyName_4_0
#define u_getPropertyValueEnum u_getPropertyValueEnum_4_0
#define u_getPropertyValueName u_getPropertyValueName_4_0
#define u_getUnicodeProperties u_getUnicodeProperties_4_0
#define u_getUnicodeVersion u_getUnicodeVersion_4_0
#define u_getVersion u_getVersion_4_0
#define u_growBufferFromStatic u_growBufferFromStatic_4_0
#define u_hasBinaryProperty u_hasBinaryProperty_4_0
#define u_init u_init_4_0
#define u_isIDIgnorable u_isIDIgnorable_4_0
#define u_isIDPart u_isIDPart_4_0
#define u_isIDStart u_isIDStart_4_0
#define u_isISOControl u_isISOControl_4_0
#define u_isJavaIDPart u_isJavaIDPart_4_0
#define u_isJavaIDStart u_isJavaIDStart_4_0
#define u_isJavaSpaceChar u_isJavaSpaceChar_4_0
#define u_isMirrored u_isMirrored_4_0
#define u_isUAlphabetic u_isUAlphabetic_4_0
#define u_isULowercase u_isULowercase_4_0
#define u_isUUppercase u_isUUppercase_4_0
#define u_isUWhiteSpace u_isUWhiteSpace_4_0
#define u_isWhitespace u_isWhitespace_4_0
#define u_isalnum u_isalnum_4_0
#define u_isalnumPOSIX u_isalnumPOSIX_4_0
#define u_isalpha u_isalpha_4_0
#define u_isbase u_isbase_4_0
#define u_isblank u_isblank_4_0
#define u_iscntrl u_iscntrl_4_0
#define u_isdefined u_isdefined_4_0
#define u_isdigit u_isdigit_4_0
#define u_isgraph u_isgraph_4_0
#define u_isgraphPOSIX u_isgraphPOSIX_4_0
#define u_islower u_islower_4_0
#define u_isprint u_isprint_4_0
#define u_isprintPOSIX u_isprintPOSIX_4_0
#define u_ispunct u_ispunct_4_0
#define u_isspace u_isspace_4_0
#define u_istitle u_istitle_4_0
#define u_isupper u_isupper_4_0
#define u_isxdigit u_isxdigit_4_0
#define u_lengthOfIdenticalLevelRun u_lengthOfIdenticalLevelRun_4_0
#define u_locbund_close u_locbund_close_4_0
#define u_locbund_getNumberFormat u_locbund_getNumberFormat_4_0
#define u_locbund_init u_locbund_init_4_0
#define u_memcasecmp u_memcasecmp_4_0
#define u_memchr u_memchr_4_0
#define u_memchr32 u_memchr32_4_0
#define u_memcmp u_memcmp_4_0
#define u_memcmpCodePointOrder u_memcmpCodePointOrder_4_0
#define u_memcpy u_memcpy_4_0
#define u_memmove u_memmove_4_0
#define u_memrchr u_memrchr_4_0
#define u_memrchr32 u_memrchr32_4_0
#define u_memset u_memset_4_0
#define u_parseMessage u_parseMessage_4_0
#define u_parseMessageWithError u_parseMessageWithError_4_0
#define u_printf_parse u_printf_parse_4_0
#define u_releaseDefaultConverter u_releaseDefaultConverter_4_0
#define u_scanf_parse u_scanf_parse_4_0
#define u_setAtomicIncDecFunctions u_setAtomicIncDecFunctions_4_0
#define u_setDataDirectory u_setDataDirectory_4_0
#define u_setMemoryFunctions u_setMemoryFunctions_4_0
#define u_setMutexFunctions u_setMutexFunctions_4_0
#define u_shapeArabic u_shapeArabic_4_0
#define u_snprintf u_snprintf_4_0
#define u_snprintf_u u_snprintf_u_4_0
#define u_sprintf u_sprintf_4_0
#define u_sprintf_u u_sprintf_u_4_0
#define u_sscanf u_sscanf_4_0
#define u_sscanf_u u_sscanf_u_4_0
#define u_strCaseCompare u_strCaseCompare_4_0
#define u_strCompare u_strCompare_4_0
#define u_strCompareIter u_strCompareIter_4_0
#define u_strFindFirst u_strFindFirst_4_0
#define u_strFindLast u_strFindLast_4_0
#define u_strFoldCase u_strFoldCase_4_0
#define u_strFromPunycode u_strFromPunycode_4_0
#define u_strFromUTF32 u_strFromUTF32_4_0
#define u_strFromUTF8 u_strFromUTF8_4_0
#define u_strFromUTF8Lenient u_strFromUTF8Lenient_4_0
#define u_strFromUTF8WithSub u_strFromUTF8WithSub_4_0
#define u_strFromWCS u_strFromWCS_4_0
#define u_strHasMoreChar32Than u_strHasMoreChar32Than_4_0
#define u_strToLower u_strToLower_4_0
#define u_strToPunycode u_strToPunycode_4_0
#define u_strToTitle u_strToTitle_4_0
#define u_strToUTF32 u_strToUTF32_4_0
#define u_strToUTF8 u_strToUTF8_4_0
#define u_strToUTF8WithSub u_strToUTF8WithSub_4_0
#define u_strToUpper u_strToUpper_4_0
#define u_strToWCS u_strToWCS_4_0
#define u_strcasecmp u_strcasecmp_4_0
#define u_strcat u_strcat_4_0
#define u_strchr u_strchr_4_0
#define u_strchr32 u_strchr32_4_0
#define u_strcmp u_strcmp_4_0
#define u_strcmpCodePointOrder u_strcmpCodePointOrder_4_0
#define u_strcmpFold u_strcmpFold_4_0
#define u_strcpy u_strcpy_4_0
#define u_strcspn u_strcspn_4_0
#define u_strlen u_strlen_4_0
#define u_strncasecmp u_strncasecmp_4_0
#define u_strncat u_strncat_4_0
#define u_strncmp u_strncmp_4_0
#define u_strncmpCodePointOrder u_strncmpCodePointOrder_4_0
#define u_strncpy u_strncpy_4_0
#define u_strpbrk u_strpbrk_4_0
#define u_strrchr u_strrchr_4_0
#define u_strrchr32 u_strrchr32_4_0
#define u_strrstr u_strrstr_4_0
#define u_strspn u_strspn_4_0
#define u_strstr u_strstr_4_0
#define u_strtok_r u_strtok_r_4_0
#define u_terminateChars u_terminateChars_4_0
#define u_terminateUChar32s u_terminateUChar32s_4_0
#define u_terminateUChars u_terminateUChars_4_0
#define u_terminateWChars u_terminateWChars_4_0
#define u_tolower u_tolower_4_0
#define u_totitle u_totitle_4_0
#define u_toupper u_toupper_4_0
#define u_uastrcpy u_uastrcpy_4_0
#define u_uastrncpy u_uastrncpy_4_0
#define u_unescape u_unescape_4_0
#define u_unescapeAt u_unescapeAt_4_0
#define u_versionFromString u_versionFromString_4_0
#define u_versionToString u_versionToString_4_0
#define u_vformatMessage u_vformatMessage_4_0
#define u_vformatMessageWithError u_vformatMessageWithError_4_0
#define u_vfprintf u_vfprintf_4_0
#define u_vfprintf_u u_vfprintf_u_4_0
#define u_vfscanf u_vfscanf_4_0
#define u_vfscanf_u u_vfscanf_u_4_0
#define u_vparseMessage u_vparseMessage_4_0
#define u_vparseMessageWithError u_vparseMessageWithError_4_0
#define u_vsnprintf u_vsnprintf_4_0
#define u_vsnprintf_u u_vsnprintf_u_4_0
#define u_vsprintf u_vsprintf_4_0
#define u_vsprintf_u u_vsprintf_u_4_0
#define u_vsscanf u_vsscanf_4_0
#define u_vsscanf_u u_vsscanf_u_4_0
#define u_writeDiff u_writeDiff_4_0
#define u_writeIdenticalLevelRun u_writeIdenticalLevelRun_4_0
#define u_writeIdenticalLevelRunTwoChars u_writeIdenticalLevelRunTwoChars_4_0
#define ubidi_addPropertyStarts ubidi_addPropertyStarts_4_0
#define ubidi_close ubidi_close_4_0
#define ubidi_closeProps ubidi_closeProps_4_0
#define ubidi_countParagraphs ubidi_countParagraphs_4_0
#define ubidi_countRuns ubidi_countRuns_4_0
#define ubidi_getClass ubidi_getClass_4_0
#define ubidi_getClassCallback ubidi_getClassCallback_4_0
#define ubidi_getCustomizedClass ubidi_getCustomizedClass_4_0
#define ubidi_getDirection ubidi_getDirection_4_0
#define ubidi_getJoiningGroup ubidi_getJoiningGroup_4_0
#define ubidi_getJoiningType ubidi_getJoiningType_4_0
#define ubidi_getLength ubidi_getLength_4_0
#define ubidi_getLevelAt ubidi_getLevelAt_4_0
#define ubidi_getLevels ubidi_getLevels_4_0
#define ubidi_getLogicalIndex ubidi_getLogicalIndex_4_0
#define ubidi_getLogicalMap ubidi_getLogicalMap_4_0
#define ubidi_getLogicalRun ubidi_getLogicalRun_4_0
#define ubidi_getMaxValue ubidi_getMaxValue_4_0
#define ubidi_getMemory ubidi_getMemory_4_0
#define ubidi_getMirror ubidi_getMirror_4_0
#define ubidi_getParaLevel ubidi_getParaLevel_4_0
#define ubidi_getParagraph ubidi_getParagraph_4_0
#define ubidi_getParagraphByIndex ubidi_getParagraphByIndex_4_0
#define ubidi_getProcessedLength ubidi_getProcessedLength_4_0
#define ubidi_getReorderingMode ubidi_getReorderingMode_4_0
#define ubidi_getReorderingOptions ubidi_getReorderingOptions_4_0
#define ubidi_getResultLength ubidi_getResultLength_4_0
#define ubidi_getRuns ubidi_getRuns_4_0
#define ubidi_getSingleton ubidi_getSingleton_4_0
#define ubidi_getText ubidi_getText_4_0
#define ubidi_getVisualIndex ubidi_getVisualIndex_4_0
#define ubidi_getVisualMap ubidi_getVisualMap_4_0
#define ubidi_getVisualRun ubidi_getVisualRun_4_0
#define ubidi_invertMap ubidi_invertMap_4_0
#define ubidi_isBidiControl ubidi_isBidiControl_4_0
#define ubidi_isInverse ubidi_isInverse_4_0
#define ubidi_isJoinControl ubidi_isJoinControl_4_0
#define ubidi_isMirrored ubidi_isMirrored_4_0
#define ubidi_isOrderParagraphsLTR ubidi_isOrderParagraphsLTR_4_0
#define ubidi_open ubidi_open_4_0
#define ubidi_openSized ubidi_openSized_4_0
#define ubidi_orderParagraphsLTR ubidi_orderParagraphsLTR_4_0
#define ubidi_reorderLogical ubidi_reorderLogical_4_0
#define ubidi_reorderVisual ubidi_reorderVisual_4_0
#define ubidi_setClassCallback ubidi_setClassCallback_4_0
#define ubidi_setInverse ubidi_setInverse_4_0
#define ubidi_setLine ubidi_setLine_4_0
#define ubidi_setPara ubidi_setPara_4_0
#define ubidi_setReorderingMode ubidi_setReorderingMode_4_0
#define ubidi_setReorderingOptions ubidi_setReorderingOptions_4_0
#define ubidi_writeReordered ubidi_writeReordered_4_0
#define ubidi_writeReverse ubidi_writeReverse_4_0
#define ublock_getCode ublock_getCode_4_0
#define ubrk_close ubrk_close_4_0
#define ubrk_countAvailable ubrk_countAvailable_4_0
#define ubrk_current ubrk_current_4_0
#define ubrk_first ubrk_first_4_0
#define ubrk_following ubrk_following_4_0
#define ubrk_getAvailable ubrk_getAvailable_4_0
#define ubrk_getLocaleByType ubrk_getLocaleByType_4_0
#define ubrk_getRuleStatus ubrk_getRuleStatus_4_0
#define ubrk_getRuleStatusVec ubrk_getRuleStatusVec_4_0
#define ubrk_isBoundary ubrk_isBoundary_4_0
#define ubrk_last ubrk_last_4_0
#define ubrk_next ubrk_next_4_0
#define ubrk_open ubrk_open_4_0
#define ubrk_openRules ubrk_openRules_4_0
#define ubrk_preceding ubrk_preceding_4_0
#define ubrk_previous ubrk_previous_4_0
#define ubrk_safeClone ubrk_safeClone_4_0
#define ubrk_setText ubrk_setText_4_0
#define ubrk_setUText ubrk_setUText_4_0
#define ubrk_swap ubrk_swap_4_0
#define ucal_add ucal_add_4_0
#define ucal_clear ucal_clear_4_0
#define ucal_clearField ucal_clearField_4_0
#define ucal_clone ucal_clone_4_0
#define ucal_close ucal_close_4_0
#define ucal_countAvailable ucal_countAvailable_4_0
#define ucal_equivalentTo ucal_equivalentTo_4_0
#define ucal_get ucal_get_4_0
#define ucal_getAttribute ucal_getAttribute_4_0
#define ucal_getAvailable ucal_getAvailable_4_0
#define ucal_getCanonicalTimeZoneID ucal_getCanonicalTimeZoneID_4_0
#define ucal_getDSTSavings ucal_getDSTSavings_4_0
#define ucal_getDefaultTimeZone ucal_getDefaultTimeZone_4_0
#define ucal_getGregorianChange ucal_getGregorianChange_4_0
#define ucal_getLimit ucal_getLimit_4_0
#define ucal_getLocaleByType ucal_getLocaleByType_4_0
#define ucal_getMillis ucal_getMillis_4_0
#define ucal_getNow ucal_getNow_4_0
#define ucal_getTZDataVersion ucal_getTZDataVersion_4_0
#define ucal_getTimeZoneDisplayName ucal_getTimeZoneDisplayName_4_0
#define ucal_inDaylightTime ucal_inDaylightTime_4_0
#define ucal_isSet ucal_isSet_4_0
#define ucal_open ucal_open_4_0
#define ucal_openCountryTimeZones ucal_openCountryTimeZones_4_0
#define ucal_openTimeZones ucal_openTimeZones_4_0
#define ucal_roll ucal_roll_4_0
#define ucal_set ucal_set_4_0
#define ucal_setAttribute ucal_setAttribute_4_0
#define ucal_setDate ucal_setDate_4_0
#define ucal_setDateTime ucal_setDateTime_4_0
#define ucal_setDefaultTimeZone ucal_setDefaultTimeZone_4_0
#define ucal_setGregorianChange ucal_setGregorianChange_4_0
#define ucal_setMillis ucal_setMillis_4_0
#define ucal_setTimeZone ucal_setTimeZone_4_0
#define ucase_addCaseClosure ucase_addCaseClosure_4_0
#define ucase_addPropertyStarts ucase_addPropertyStarts_4_0
#define ucase_addStringCaseClosure ucase_addStringCaseClosure_4_0
#define ucase_close ucase_close_4_0
#define ucase_fold ucase_fold_4_0
#define ucase_getCaseLocale ucase_getCaseLocale_4_0
#define ucase_getSingleton ucase_getSingleton_4_0
#define ucase_getType ucase_getType_4_0
#define ucase_getTypeOrIgnorable ucase_getTypeOrIgnorable_4_0
#define ucase_hasBinaryProperty ucase_hasBinaryProperty_4_0
#define ucase_isCaseSensitive ucase_isCaseSensitive_4_0
#define ucase_isSoftDotted ucase_isSoftDotted_4_0
#define ucase_toFullFolding ucase_toFullFolding_4_0
#define ucase_toFullLower ucase_toFullLower_4_0
#define ucase_toFullTitle ucase_toFullTitle_4_0
#define ucase_toFullUpper ucase_toFullUpper_4_0
#define ucase_tolower ucase_tolower_4_0
#define ucase_totitle ucase_totitle_4_0
#define ucase_toupper ucase_toupper_4_0
#define ucasemap_close ucasemap_close_4_0
#define ucasemap_getBreakIterator ucasemap_getBreakIterator_4_0
#define ucasemap_getLocale ucasemap_getLocale_4_0
#define ucasemap_getOptions ucasemap_getOptions_4_0
#define ucasemap_open ucasemap_open_4_0
#define ucasemap_setBreakIterator ucasemap_setBreakIterator_4_0
#define ucasemap_setLocale ucasemap_setLocale_4_0
#define ucasemap_setOptions ucasemap_setOptions_4_0
#define ucasemap_toTitle ucasemap_toTitle_4_0
#define ucasemap_utf8FoldCase ucasemap_utf8FoldCase_4_0
#define ucasemap_utf8ToLower ucasemap_utf8ToLower_4_0
#define ucasemap_utf8ToTitle ucasemap_utf8ToTitle_4_0
#define ucasemap_utf8ToUpper ucasemap_utf8ToUpper_4_0
#define uchar_addPropertyStarts uchar_addPropertyStarts_4_0
#define uchar_getHST uchar_getHST_4_0
#define uchar_swapNames uchar_swapNames_4_0
#define ucln_common_registerCleanup ucln_common_registerCleanup_4_0
#define ucln_i18n_registerCleanup ucln_i18n_registerCleanup_4_0
#define ucln_io_registerCleanup ucln_io_registerCleanup_4_0
#define ucln_lib_cleanup ucln_lib_cleanup_4_0
#define ucln_registerCleanup ucln_registerCleanup_4_0
#define ucnv_MBCSFromUChar32 ucnv_MBCSFromUChar32_4_0
#define ucnv_MBCSFromUnicodeWithOffsets ucnv_MBCSFromUnicodeWithOffsets_4_0
#define ucnv_MBCSGetFilteredUnicodeSetForUnicode ucnv_MBCSGetFilteredUnicodeSetForUnicode_4_0
#define ucnv_MBCSGetType ucnv_MBCSGetType_4_0
#define ucnv_MBCSGetUnicodeSetForUnicode ucnv_MBCSGetUnicodeSetForUnicode_4_0
#define ucnv_MBCSIsLeadByte ucnv_MBCSIsLeadByte_4_0
#define ucnv_MBCSSimpleGetNextUChar ucnv_MBCSSimpleGetNextUChar_4_0
#define ucnv_MBCSToUnicodeWithOffsets ucnv_MBCSToUnicodeWithOffsets_4_0
#define ucnv_bld_countAvailableConverters ucnv_bld_countAvailableConverters_4_0
#define ucnv_bld_getAvailableConverter ucnv_bld_getAvailableConverter_4_0
#define ucnv_cbFromUWriteBytes ucnv_cbFromUWriteBytes_4_0
#define ucnv_cbFromUWriteSub ucnv_cbFromUWriteSub_4_0
#define ucnv_cbFromUWriteUChars ucnv_cbFromUWriteUChars_4_0
#define ucnv_cbToUWriteSub ucnv_cbToUWriteSub_4_0
#define ucnv_cbToUWriteUChars ucnv_cbToUWriteUChars_4_0
#define ucnv_close ucnv_close_4_0
#define ucnv_compareNames ucnv_compareNames_4_0
#define ucnv_convert ucnv_convert_4_0
#define ucnv_convertEx ucnv_convertEx_4_0
#define ucnv_countAliases ucnv_countAliases_4_0
#define ucnv_countAvailable ucnv_countAvailable_4_0
#define ucnv_countStandards ucnv_countStandards_4_0
#define ucnv_createAlgorithmicConverter ucnv_createAlgorithmicConverter_4_0
#define ucnv_createConverter ucnv_createConverter_4_0
#define ucnv_createConverterFromPackage ucnv_createConverterFromPackage_4_0
#define ucnv_createConverterFromSharedData ucnv_createConverterFromSharedData_4_0
#define ucnv_detectUnicodeSignature ucnv_detectUnicodeSignature_4_0
#define ucnv_extContinueMatchFromU ucnv_extContinueMatchFromU_4_0
#define ucnv_extContinueMatchToU ucnv_extContinueMatchToU_4_0
#define ucnv_extGetUnicodeSet ucnv_extGetUnicodeSet_4_0
#define ucnv_extInitialMatchFromU ucnv_extInitialMatchFromU_4_0
#define ucnv_extInitialMatchToU ucnv_extInitialMatchToU_4_0
#define ucnv_extSimpleMatchFromU ucnv_extSimpleMatchFromU_4_0
#define ucnv_extSimpleMatchToU ucnv_extSimpleMatchToU_4_0
#define ucnv_fixFileSeparator ucnv_fixFileSeparator_4_0
#define ucnv_flushCache ucnv_flushCache_4_0
#define ucnv_fromAlgorithmic ucnv_fromAlgorithmic_4_0
#define ucnv_fromUChars ucnv_fromUChars_4_0
#define ucnv_fromUCountPending ucnv_fromUCountPending_4_0
#define ucnv_fromUWriteBytes ucnv_fromUWriteBytes_4_0
#define ucnv_fromUnicode ucnv_fromUnicode_4_0
#define ucnv_fromUnicode_UTF8 ucnv_fromUnicode_UTF8_4_0
#define ucnv_fromUnicode_UTF8_OFFSETS_LOGIC ucnv_fromUnicode_UTF8_OFFSETS_LOGIC_4_0
#define ucnv_getAlias ucnv_getAlias_4_0
#define ucnv_getAliases ucnv_getAliases_4_0
#define ucnv_getAvailableName ucnv_getAvailableName_4_0
#define ucnv_getCCSID ucnv_getCCSID_4_0
#define ucnv_getCanonicalName ucnv_getCanonicalName_4_0
#define ucnv_getCompleteUnicodeSet ucnv_getCompleteUnicodeSet_4_0
#define ucnv_getDefaultName ucnv_getDefaultName_4_0
#define ucnv_getDisplayName ucnv_getDisplayName_4_0
#define ucnv_getFromUCallBack ucnv_getFromUCallBack_4_0
#define ucnv_getInvalidChars ucnv_getInvalidChars_4_0
#define ucnv_getInvalidUChars ucnv_getInvalidUChars_4_0
#define ucnv_getMaxCharSize ucnv_getMaxCharSize_4_0
#define ucnv_getMinCharSize ucnv_getMinCharSize_4_0
#define ucnv_getName ucnv_getName_4_0
#define ucnv_getNextUChar ucnv_getNextUChar_4_0
#define ucnv_getNonSurrogateUnicodeSet ucnv_getNonSurrogateUnicodeSet_4_0
#define ucnv_getPlatform ucnv_getPlatform_4_0
#define ucnv_getStandard ucnv_getStandard_4_0
#define ucnv_getStandardName ucnv_getStandardName_4_0
#define ucnv_getStarters ucnv_getStarters_4_0
#define ucnv_getSubstChars ucnv_getSubstChars_4_0
#define ucnv_getToUCallBack ucnv_getToUCallBack_4_0
#define ucnv_getType ucnv_getType_4_0
#define ucnv_getUnicodeSet ucnv_getUnicodeSet_4_0
#define ucnv_incrementRefCount ucnv_incrementRefCount_4_0
#define ucnv_io_countKnownConverters ucnv_io_countKnownConverters_4_0
#define ucnv_io_getConverterName ucnv_io_getConverterName_4_0
#define ucnv_io_stripASCIIForCompare ucnv_io_stripASCIIForCompare_4_0
#define ucnv_io_stripEBCDICForCompare ucnv_io_stripEBCDICForCompare_4_0
#define ucnv_isAmbiguous ucnv_isAmbiguous_4_0
#define ucnv_load ucnv_load_4_0
#define ucnv_loadSharedData ucnv_loadSharedData_4_0
#define ucnv_open ucnv_open_4_0
#define ucnv_openAllNames ucnv_openAllNames_4_0
#define ucnv_openCCSID ucnv_openCCSID_4_0
#define ucnv_openPackage ucnv_openPackage_4_0
#define ucnv_openStandardNames ucnv_openStandardNames_4_0
#define ucnv_openU ucnv_openU_4_0
#define ucnv_reset ucnv_reset_4_0
#define ucnv_resetFromUnicode ucnv_resetFromUnicode_4_0
#define ucnv_resetToUnicode ucnv_resetToUnicode_4_0
#define ucnv_safeClone ucnv_safeClone_4_0
#define ucnv_setDefaultName ucnv_setDefaultName_4_0
#define ucnv_setFallback ucnv_setFallback_4_0
#define ucnv_setFromUCallBack ucnv_setFromUCallBack_4_0
#define ucnv_setSubstChars ucnv_setSubstChars_4_0
#define ucnv_setSubstString ucnv_setSubstString_4_0
#define ucnv_setToUCallBack ucnv_setToUCallBack_4_0
#define ucnv_swap ucnv_swap_4_0
#define ucnv_swapAliases ucnv_swapAliases_4_0
#define ucnv_toAlgorithmic ucnv_toAlgorithmic_4_0
#define ucnv_toUChars ucnv_toUChars_4_0
#define ucnv_toUCountPending ucnv_toUCountPending_4_0
#define ucnv_toUWriteCodePoint ucnv_toUWriteCodePoint_4_0
#define ucnv_toUWriteUChars ucnv_toUWriteUChars_4_0
#define ucnv_toUnicode ucnv_toUnicode_4_0
#define ucnv_unload ucnv_unload_4_0
#define ucnv_unloadSharedDataIfReady ucnv_unloadSharedDataIfReady_4_0
#define ucnv_usesFallback ucnv_usesFallback_4_0
#define ucol_allocWeights ucol_allocWeights_4_0
#define ucol_assembleTailoringTable ucol_assembleTailoringTable_4_0
#define ucol_calcSortKey ucol_calcSortKey_4_0
#define ucol_calcSortKeySimpleTertiary ucol_calcSortKeySimpleTertiary_4_0
#define ucol_cloneBinary ucol_cloneBinary_4_0
#define ucol_cloneRuleData ucol_cloneRuleData_4_0
#define ucol_close ucol_close_4_0
#define ucol_closeElements ucol_closeElements_4_0
#define ucol_countAvailable ucol_countAvailable_4_0
#define ucol_createElements ucol_createElements_4_0
#define ucol_doCE ucol_doCE_4_0
#define ucol_equal ucol_equal_4_0
#define ucol_equals ucol_equals_4_0
#define ucol_forgetUCA ucol_forgetUCA_4_0
#define ucol_getAttribute ucol_getAttribute_4_0
#define ucol_getAttributeOrDefault ucol_getAttributeOrDefault_4_0
#define ucol_getAvailable ucol_getAvailable_4_0
#define ucol_getBound ucol_getBound_4_0
#define ucol_getCEStrengthDifference ucol_getCEStrengthDifference_4_0
#define ucol_getContractions ucol_getContractions_4_0
#define ucol_getContractionsAndExpansions ucol_getContractionsAndExpansions_4_0
#define ucol_getDisplayName ucol_getDisplayName_4_0
#define ucol_getFirstCE ucol_getFirstCE_4_0
#define ucol_getFunctionalEquivalent ucol_getFunctionalEquivalent_4_0
#define ucol_getKeywordValues ucol_getKeywordValues_4_0
#define ucol_getKeywords ucol_getKeywords_4_0
#define ucol_getLocale ucol_getLocale_4_0
#define ucol_getLocaleByType ucol_getLocaleByType_4_0
#define ucol_getMaxExpansion ucol_getMaxExpansion_4_0
#define ucol_getNextCE ucol_getNextCE_4_0
#define ucol_getOffset ucol_getOffset_4_0
#define ucol_getPrevCE ucol_getPrevCE_4_0
#define ucol_getRules ucol_getRules_4_0
#define ucol_getRulesEx ucol_getRulesEx_4_0
#define ucol_getShortDefinitionString ucol_getShortDefinitionString_4_0
#define ucol_getSortKey ucol_getSortKey_4_0
#define ucol_getSortKeySize ucol_getSortKeySize_4_0
#define ucol_getSortKeyWithAllocation ucol_getSortKeyWithAllocation_4_0
#define ucol_getStrength ucol_getStrength_4_0
#define ucol_getTailoredSet ucol_getTailoredSet_4_0
#define ucol_getUCAVersion ucol_getUCAVersion_4_0
#define ucol_getUnsafeSet ucol_getUnsafeSet_4_0
#define ucol_getVariableTop ucol_getVariableTop_4_0
#define ucol_getVersion ucol_getVersion_4_0
#define ucol_greater ucol_greater_4_0
#define ucol_greaterOrEqual ucol_greaterOrEqual_4_0
#define ucol_initBuffers ucol_initBuffers_4_0
#define ucol_initCollator ucol_initCollator_4_0
#define ucol_initInverseUCA ucol_initInverseUCA_4_0
#define ucol_initUCA ucol_initUCA_4_0
#define ucol_inv_getNextCE ucol_inv_getNextCE_4_0
#define ucol_inv_getPrevCE ucol_inv_getPrevCE_4_0
#define ucol_isTailored ucol_isTailored_4_0
#define ucol_keyHashCode ucol_keyHashCode_4_0
#define ucol_mergeSortkeys ucol_mergeSortkeys_4_0
#define ucol_next ucol_next_4_0
#define ucol_nextProcessed ucol_nextProcessed_4_0
#define ucol_nextSortKeyPart ucol_nextSortKeyPart_4_0
#define ucol_nextWeight ucol_nextWeight_4_0
#define ucol_normalizeShortDefinitionString ucol_normalizeShortDefinitionString_4_0
#define ucol_open ucol_open_4_0
#define ucol_openAvailableLocales ucol_openAvailableLocales_4_0
#define ucol_openBinary ucol_openBinary_4_0
#define ucol_openElements ucol_openElements_4_0
#define ucol_openFromShortString ucol_openFromShortString_4_0
#define ucol_openRules ucol_openRules_4_0
#define ucol_open_internal ucol_open_internal_4_0
#define ucol_prepareShortStringOpen ucol_prepareShortStringOpen_4_0
#define ucol_previous ucol_previous_4_0
#define ucol_previousProcessed ucol_previousProcessed_4_0
#define ucol_primaryOrder ucol_primaryOrder_4_0
#define ucol_prv_getSpecialCE ucol_prv_getSpecialCE_4_0
#define ucol_prv_getSpecialPrevCE ucol_prv_getSpecialPrevCE_4_0
#define ucol_reset ucol_reset_4_0
#define ucol_restoreVariableTop ucol_restoreVariableTop_4_0
#define ucol_safeClone ucol_safeClone_4_0
#define ucol_secondaryOrder ucol_secondaryOrder_4_0
#define ucol_setAttribute ucol_setAttribute_4_0
#define ucol_setOffset ucol_setOffset_4_0
#define ucol_setOptionsFromHeader ucol_setOptionsFromHeader_4_0
#define ucol_setReqValidLocales ucol_setReqValidLocales_4_0
#define ucol_setStrength ucol_setStrength_4_0
#define ucol_setText ucol_setText_4_0
#define ucol_setVariableTop ucol_setVariableTop_4_0
#define ucol_strcoll ucol_strcoll_4_0
#define ucol_strcollIter ucol_strcollIter_4_0
#define ucol_swap ucol_swap_4_0
#define ucol_swapBinary ucol_swapBinary_4_0
#define ucol_swapInverseUCA ucol_swapInverseUCA_4_0
#define ucol_tertiaryOrder ucol_tertiaryOrder_4_0
#define ucol_tok_assembleTokenList ucol_tok_assembleTokenList_4_0
#define ucol_tok_closeTokenList ucol_tok_closeTokenList_4_0
#define ucol_tok_getNextArgument ucol_tok_getNextArgument_4_0
#define ucol_tok_initTokenList ucol_tok_initTokenList_4_0
#define ucol_tok_parseNextToken ucol_tok_parseNextToken_4_0
#define ucol_updateInternalState ucol_updateInternalState_4_0
#define ucsdet_close ucsdet_close_4_0
#define ucsdet_detect ucsdet_detect_4_0
#define ucsdet_detectAll ucsdet_detectAll_4_0
#define ucsdet_enableInputFilter ucsdet_enableInputFilter_4_0
#define ucsdet_getAllDetectableCharsets ucsdet_getAllDetectableCharsets_4_0
#define ucsdet_getConfidence ucsdet_getConfidence_4_0
#define ucsdet_getLanguage ucsdet_getLanguage_4_0
#define ucsdet_getName ucsdet_getName_4_0
#define ucsdet_getUChars ucsdet_getUChars_4_0
#define ucsdet_isInputFilterEnabled ucsdet_isInputFilterEnabled_4_0
#define ucsdet_open ucsdet_open_4_0
#define ucsdet_setDeclaredEncoding ucsdet_setDeclaredEncoding_4_0
#define ucsdet_setText ucsdet_setText_4_0
#define ucurr_countCurrencies ucurr_countCurrencies_4_0
#define ucurr_forLocale ucurr_forLocale_4_0
#define ucurr_forLocaleAndDate ucurr_forLocaleAndDate_4_0
#define ucurr_getDefaultFractionDigits ucurr_getDefaultFractionDigits_4_0
#define ucurr_getName ucurr_getName_4_0
#define ucurr_getRoundingIncrement ucurr_getRoundingIncrement_4_0
#define ucurr_openISOCurrencies ucurr_openISOCurrencies_4_0
#define ucurr_register ucurr_register_4_0
#define ucurr_unregister ucurr_unregister_4_0
#define udat_applyPattern udat_applyPattern_4_0
#define udat_clone udat_clone_4_0
#define udat_close udat_close_4_0
#define udat_countAvailable udat_countAvailable_4_0
#define udat_countSymbols udat_countSymbols_4_0
#define udat_format udat_format_4_0
#define udat_get2DigitYearStart udat_get2DigitYearStart_4_0
#define udat_getAvailable udat_getAvailable_4_0
#define udat_getCalendar udat_getCalendar_4_0
#define udat_getLocaleByType udat_getLocaleByType_4_0
#define udat_getNumberFormat udat_getNumberFormat_4_0
#define udat_getSymbols udat_getSymbols_4_0
#define udat_isLenient udat_isLenient_4_0
#define udat_open udat_open_4_0
#define udat_parse udat_parse_4_0
#define udat_parseCalendar udat_parseCalendar_4_0
#define udat_set2DigitYearStart udat_set2DigitYearStart_4_0
#define udat_setCalendar udat_setCalendar_4_0
#define udat_setLenient udat_setLenient_4_0
#define udat_setNumberFormat udat_setNumberFormat_4_0
#define udat_setSymbols udat_setSymbols_4_0
#define udat_toPattern udat_toPattern_4_0
#define udata_checkCommonData udata_checkCommonData_4_0
#define udata_close udata_close_4_0
#define udata_closeSwapper udata_closeSwapper_4_0
#define udata_getHeaderSize udata_getHeaderSize_4_0
#define udata_getInfo udata_getInfo_4_0
#define udata_getInfoSize udata_getInfoSize_4_0
#define udata_getLength udata_getLength_4_0
#define udata_getMemory udata_getMemory_4_0
#define udata_getRawMemory udata_getRawMemory_4_0
#define udata_open udata_open_4_0
#define udata_openChoice udata_openChoice_4_0
#define udata_openSwapper udata_openSwapper_4_0
#define udata_openSwapperForInputData udata_openSwapperForInputData_4_0
#define udata_printError udata_printError_4_0
#define udata_readInt16 udata_readInt16_4_0
#define udata_readInt32 udata_readInt32_4_0
#define udata_setAppData udata_setAppData_4_0
#define udata_setCommonData udata_setCommonData_4_0
#define udata_setFileAccess udata_setFileAccess_4_0
#define udata_swapDataHeader udata_swapDataHeader_4_0
#define udata_swapInvStringBlock udata_swapInvStringBlock_4_0
#define udatpg_addPattern udatpg_addPattern_4_0
#define udatpg_clone udatpg_clone_4_0
#define udatpg_close udatpg_close_4_0
#define udatpg_getAppendItemFormat udatpg_getAppendItemFormat_4_0
#define udatpg_getAppendItemName udatpg_getAppendItemName_4_0
#define udatpg_getBaseSkeleton udatpg_getBaseSkeleton_4_0
#define udatpg_getBestPattern udatpg_getBestPattern_4_0
#define udatpg_getDateTimeFormat udatpg_getDateTimeFormat_4_0
#define udatpg_getDecimal udatpg_getDecimal_4_0
#define udatpg_getPatternForSkeleton udatpg_getPatternForSkeleton_4_0
#define udatpg_getSkeleton udatpg_getSkeleton_4_0
#define udatpg_open udatpg_open_4_0
#define udatpg_openBaseSkeletons udatpg_openBaseSkeletons_4_0
#define udatpg_openEmpty udatpg_openEmpty_4_0
#define udatpg_openSkeletons udatpg_openSkeletons_4_0
#define udatpg_replaceFieldTypes udatpg_replaceFieldTypes_4_0
#define udatpg_setAppendItemFormat udatpg_setAppendItemFormat_4_0
#define udatpg_setAppendItemName udatpg_setAppendItemName_4_0
#define udatpg_setDateTimeFormat udatpg_setDateTimeFormat_4_0
#define udatpg_setDecimal udatpg_setDecimal_4_0
#define uenum_close uenum_close_4_0
#define uenum_count uenum_count_4_0
#define uenum_next uenum_next_4_0
#define uenum_nextDefault uenum_nextDefault_4_0
#define uenum_openCharStringsEnumeration uenum_openCharStringsEnumeration_4_0
#define uenum_openStringEnumeration uenum_openStringEnumeration_4_0
#define uenum_reset uenum_reset_4_0
#define uenum_unext uenum_unext_4_0
#define uenum_unextDefault uenum_unextDefault_4_0
#define ufile_close_translit ufile_close_translit_4_0
#define ufile_fill_uchar_buffer ufile_fill_uchar_buffer_4_0
#define ufile_flush_translit ufile_flush_translit_4_0
#define ufile_getch ufile_getch_4_0
#define ufile_getch32 ufile_getch32_4_0
#define ufmt_64tou ufmt_64tou_4_0
#define ufmt_defaultCPToUnicode ufmt_defaultCPToUnicode_4_0
#define ufmt_digitvalue ufmt_digitvalue_4_0
#define ufmt_isdigit ufmt_isdigit_4_0
#define ufmt_ptou ufmt_ptou_4_0
#define ufmt_uto64 ufmt_uto64_4_0
#define ufmt_utop ufmt_utop_4_0
#define uhash_close uhash_close_4_0
#define uhash_compareCaselessUnicodeString uhash_compareCaselessUnicodeString_4_0
#define uhash_compareChars uhash_compareChars_4_0
#define uhash_compareIChars uhash_compareIChars_4_0
#define uhash_compareLong uhash_compareLong_4_0
#define uhash_compareUChars uhash_compareUChars_4_0
#define uhash_compareUnicodeString uhash_compareUnicodeString_4_0
#define uhash_count uhash_count_4_0
#define uhash_deleteHashtable uhash_deleteHashtable_4_0
#define uhash_deleteUVector uhash_deleteUVector_4_0
#define uhash_deleteUnicodeString uhash_deleteUnicodeString_4_0
#define uhash_equals uhash_equals_4_0
#define uhash_find uhash_find_4_0
#define uhash_freeBlock uhash_freeBlock_4_0
#define uhash_get uhash_get_4_0
#define uhash_geti uhash_geti_4_0
#define uhash_hashCaselessUnicodeString uhash_hashCaselessUnicodeString_4_0
#define uhash_hashChars uhash_hashChars_4_0
#define uhash_hashIChars uhash_hashIChars_4_0
#define uhash_hashLong uhash_hashLong_4_0
#define uhash_hashUChars uhash_hashUChars_4_0
#define uhash_hashUCharsN uhash_hashUCharsN_4_0
#define uhash_hashUnicodeString uhash_hashUnicodeString_4_0
#define uhash_iget uhash_iget_4_0
#define uhash_igeti uhash_igeti_4_0
#define uhash_init uhash_init_4_0
#define uhash_iput uhash_iput_4_0
#define uhash_iputi uhash_iputi_4_0
#define uhash_iremove uhash_iremove_4_0
#define uhash_iremovei uhash_iremovei_4_0
#define uhash_nextElement uhash_nextElement_4_0
#define uhash_open uhash_open_4_0
#define uhash_openSize uhash_openSize_4_0
#define uhash_put uhash_put_4_0
#define uhash_puti uhash_puti_4_0
#define uhash_remove uhash_remove_4_0
#define uhash_removeAll uhash_removeAll_4_0
#define uhash_removeElement uhash_removeElement_4_0
#define uhash_removei uhash_removei_4_0
#define uhash_setKeyComparator uhash_setKeyComparator_4_0
#define uhash_setKeyDeleter uhash_setKeyDeleter_4_0
#define uhash_setKeyHasher uhash_setKeyHasher_4_0
#define uhash_setResizePolicy uhash_setResizePolicy_4_0
#define uhash_setValueComparator uhash_setValueComparator_4_0
#define uhash_setValueDeleter uhash_setValueDeleter_4_0
#define uhst_addPropertyStarts uhst_addPropertyStarts_4_0
#define uidna_IDNToASCII uidna_IDNToASCII_4_0
#define uidna_IDNToUnicode uidna_IDNToUnicode_4_0
#define uidna_compare uidna_compare_4_0
#define uidna_toASCII uidna_toASCII_4_0
#define uidna_toUnicode uidna_toUnicode_4_0
#define uiter_current32 uiter_current32_4_0
#define uiter_getState uiter_getState_4_0
#define uiter_next32 uiter_next32_4_0
#define uiter_previous32 uiter_previous32_4_0
#define uiter_setCharacterIterator uiter_setCharacterIterator_4_0
#define uiter_setReplaceable uiter_setReplaceable_4_0
#define uiter_setState uiter_setState_4_0
#define uiter_setString uiter_setString_4_0
#define uiter_setUTF16BE uiter_setUTF16BE_4_0
#define uiter_setUTF8 uiter_setUTF8_4_0
#define uloc_acceptLanguage uloc_acceptLanguage_4_0
#define uloc_acceptLanguageFromHTTP uloc_acceptLanguageFromHTTP_4_0
#define uloc_addLikelySubtags uloc_addLikelySubtags_4_0
#define uloc_canonicalize uloc_canonicalize_4_0
#define uloc_countAvailable uloc_countAvailable_4_0
#define uloc_getAvailable uloc_getAvailable_4_0
#define uloc_getBaseName uloc_getBaseName_4_0
#define uloc_getCharacterOrientation uloc_getCharacterOrientation_4_0
#define uloc_getCountry uloc_getCountry_4_0
#define uloc_getDefault uloc_getDefault_4_0
#define uloc_getDisplayCountry uloc_getDisplayCountry_4_0
#define uloc_getDisplayKeyword uloc_getDisplayKeyword_4_0
#define uloc_getDisplayKeywordValue uloc_getDisplayKeywordValue_4_0
#define uloc_getDisplayLanguage uloc_getDisplayLanguage_4_0
#define uloc_getDisplayName uloc_getDisplayName_4_0
#define uloc_getDisplayScript uloc_getDisplayScript_4_0
#define uloc_getDisplayVariant uloc_getDisplayVariant_4_0
#define uloc_getISO3Country uloc_getISO3Country_4_0
#define uloc_getISO3Language uloc_getISO3Language_4_0
#define uloc_getISOCountries uloc_getISOCountries_4_0
#define uloc_getISOLanguages uloc_getISOLanguages_4_0
#define uloc_getKeywordValue uloc_getKeywordValue_4_0
#define uloc_getLCID uloc_getLCID_4_0
#define uloc_getLanguage uloc_getLanguage_4_0
#define uloc_getLineOrientation uloc_getLineOrientation_4_0
#define uloc_getLocaleForLCID uloc_getLocaleForLCID_4_0
#define uloc_getName uloc_getName_4_0
#define uloc_getParent uloc_getParent_4_0
#define uloc_getScript uloc_getScript_4_0
#define uloc_getVariant uloc_getVariant_4_0
#define uloc_minimizeSubtags uloc_minimizeSubtags_4_0
#define uloc_openKeywordList uloc_openKeywordList_4_0
#define uloc_openKeywords uloc_openKeywords_4_0
#define uloc_setDefault uloc_setDefault_4_0
#define uloc_setKeywordValue uloc_setKeywordValue_4_0
#define ulocdata_close ulocdata_close_4_0
#define ulocdata_getDelimiter ulocdata_getDelimiter_4_0
#define ulocdata_getExemplarSet ulocdata_getExemplarSet_4_0
#define ulocdata_getMeasurementSystem ulocdata_getMeasurementSystem_4_0
#define ulocdata_getNoSubstitute ulocdata_getNoSubstitute_4_0
#define ulocdata_getPaperSize ulocdata_getPaperSize_4_0
#define ulocdata_open ulocdata_open_4_0
#define ulocdata_setNoSubstitute ulocdata_setNoSubstitute_4_0
#define umsg_applyPattern umsg_applyPattern_4_0
#define umsg_autoQuoteApostrophe umsg_autoQuoteApostrophe_4_0
#define umsg_clone umsg_clone_4_0
#define umsg_close umsg_close_4_0
#define umsg_format umsg_format_4_0
#define umsg_getLocale umsg_getLocale_4_0
#define umsg_open umsg_open_4_0
#define umsg_parse umsg_parse_4_0
#define umsg_setLocale umsg_setLocale_4_0
#define umsg_toPattern umsg_toPattern_4_0
#define umsg_vformat umsg_vformat_4_0
#define umsg_vparse umsg_vparse_4_0
#define umtx_atomic_dec umtx_atomic_dec_4_0
#define umtx_atomic_inc umtx_atomic_inc_4_0
#define umtx_cleanup umtx_cleanup_4_0
#define umtx_destroy umtx_destroy_4_0
#define umtx_init umtx_init_4_0
#define umtx_lock umtx_lock_4_0
#define umtx_unlock umtx_unlock_4_0
#define unorm_addPropertyStarts unorm_addPropertyStarts_4_0
#define unorm_closeIter unorm_closeIter_4_0
#define unorm_compare unorm_compare_4_0
#define unorm_compose unorm_compose_4_0
#define unorm_concatenate unorm_concatenate_4_0
#define unorm_decompose unorm_decompose_4_0
#define unorm_getCanonStartSet unorm_getCanonStartSet_4_0
#define unorm_getCanonicalDecomposition unorm_getCanonicalDecomposition_4_0
#define unorm_getDecomposition unorm_getDecomposition_4_0
#define unorm_getFCD16FromCodePoint unorm_getFCD16FromCodePoint_4_0
#define unorm_getFCDTrie unorm_getFCDTrie_4_0
#define unorm_getNX unorm_getNX_4_0
#define unorm_getQuickCheck unorm_getQuickCheck_4_0
#define unorm_getUnicodeVersion unorm_getUnicodeVersion_4_0
#define unorm_haveData unorm_haveData_4_0
#define unorm_internalIsFullCompositionExclusion unorm_internalIsFullCompositionExclusion_4_0
#define unorm_internalNormalize unorm_internalNormalize_4_0
#define unorm_internalNormalizeWithNX unorm_internalNormalizeWithNX_4_0
#define unorm_internalQuickCheck unorm_internalQuickCheck_4_0
#define unorm_isCanonSafeStart unorm_isCanonSafeStart_4_0
#define unorm_isNFSkippable unorm_isNFSkippable_4_0
#define unorm_isNormalized unorm_isNormalized_4_0
#define unorm_isNormalizedWithOptions unorm_isNormalizedWithOptions_4_0
#define unorm_next unorm_next_4_0
#define unorm_normalize unorm_normalize_4_0
#define unorm_openIter unorm_openIter_4_0
#define unorm_previous unorm_previous_4_0
#define unorm_quickCheck unorm_quickCheck_4_0
#define unorm_quickCheckWithOptions unorm_quickCheckWithOptions_4_0
#define unorm_setIter unorm_setIter_4_0
#define unum_applyPattern unum_applyPattern_4_0
#define unum_clone unum_clone_4_0
#define unum_close unum_close_4_0
#define unum_countAvailable unum_countAvailable_4_0
#define unum_format unum_format_4_0
#define unum_formatDouble unum_formatDouble_4_0
#define unum_formatDoubleCurrency unum_formatDoubleCurrency_4_0
#define unum_formatInt64 unum_formatInt64_4_0
#define unum_getAttribute unum_getAttribute_4_0
#define unum_getAvailable unum_getAvailable_4_0
#define unum_getDoubleAttribute unum_getDoubleAttribute_4_0
#define unum_getLocaleByType unum_getLocaleByType_4_0
#define unum_getSymbol unum_getSymbol_4_0
#define unum_getTextAttribute unum_getTextAttribute_4_0
#define unum_open unum_open_4_0
#define unum_parse unum_parse_4_0
#define unum_parseDouble unum_parseDouble_4_0
#define unum_parseDoubleCurrency unum_parseDoubleCurrency_4_0
#define unum_parseInt64 unum_parseInt64_4_0
#define unum_setAttribute unum_setAttribute_4_0
#define unum_setDoubleAttribute unum_setDoubleAttribute_4_0
#define unum_setSymbol unum_setSymbol_4_0
#define unum_setTextAttribute unum_setTextAttribute_4_0
#define unum_toPattern unum_toPattern_4_0
#define upname_swap upname_swap_4_0
#define uprops_getSource uprops_getSource_4_0
#define upropsvec_addPropertyStarts upropsvec_addPropertyStarts_4_0
#define uprv_asciiFromEbcdic uprv_asciiFromEbcdic_4_0
#define uprv_asciitolower uprv_asciitolower_4_0
#define uprv_ceil uprv_ceil_4_0
#define uprv_cnttab_addContraction uprv_cnttab_addContraction_4_0
#define uprv_cnttab_changeContraction uprv_cnttab_changeContraction_4_0
#define uprv_cnttab_changeLastCE uprv_cnttab_changeLastCE_4_0
#define uprv_cnttab_clone uprv_cnttab_clone_4_0
#define uprv_cnttab_close uprv_cnttab_close_4_0
#define uprv_cnttab_constructTable uprv_cnttab_constructTable_4_0
#define uprv_cnttab_findCE uprv_cnttab_findCE_4_0
#define uprv_cnttab_findCP uprv_cnttab_findCP_4_0
#define uprv_cnttab_getCE uprv_cnttab_getCE_4_0
#define uprv_cnttab_insertContraction uprv_cnttab_insertContraction_4_0
#define uprv_cnttab_isTailored uprv_cnttab_isTailored_4_0
#define uprv_cnttab_open uprv_cnttab_open_4_0
#define uprv_cnttab_setContraction uprv_cnttab_setContraction_4_0
#define uprv_compareASCIIPropertyNames uprv_compareASCIIPropertyNames_4_0
#define uprv_compareEBCDICPropertyNames uprv_compareEBCDICPropertyNames_4_0
#define uprv_compareInvAscii uprv_compareInvAscii_4_0
#define uprv_compareInvEbcdic uprv_compareInvEbcdic_4_0
#define uprv_convertToLCID uprv_convertToLCID_4_0
#define uprv_convertToPosix uprv_convertToPosix_4_0
#define uprv_copyAscii uprv_copyAscii_4_0
#define uprv_copyEbcdic uprv_copyEbcdic_4_0
#define uprv_ebcdicFromAscii uprv_ebcdicFromAscii_4_0
#define uprv_ebcdictolower uprv_ebcdictolower_4_0
#define uprv_fabs uprv_fabs_4_0
#define uprv_floor uprv_floor_4_0
#define uprv_fmax uprv_fmax_4_0
#define uprv_fmin uprv_fmin_4_0
#define uprv_fmod uprv_fmod_4_0
#define uprv_free uprv_free_4_0
#define uprv_getCharNameCharacters uprv_getCharNameCharacters_4_0
#define uprv_getDefaultCodepage uprv_getDefaultCodepage_4_0
#define uprv_getDefaultLocaleID uprv_getDefaultLocaleID_4_0
#define uprv_getInfinity uprv_getInfinity_4_0
#define uprv_getMaxCharNameLength uprv_getMaxCharNameLength_4_0
#define uprv_getMaxValues uprv_getMaxValues_4_0
#define uprv_getNaN uprv_getNaN_4_0
#define uprv_getStaticCurrencyName uprv_getStaticCurrencyName_4_0
#define uprv_getUTCtime uprv_getUTCtime_4_0
#define uprv_haveProperties uprv_haveProperties_4_0
#define uprv_init_collIterate uprv_init_collIterate_4_0
#define uprv_init_pce uprv_init_pce_4_0
#define uprv_int32Comparator uprv_int32Comparator_4_0
#define uprv_isInfinite uprv_isInfinite_4_0
#define uprv_isInvariantString uprv_isInvariantString_4_0
#define uprv_isInvariantUString uprv_isInvariantUString_4_0
#define uprv_isNaN uprv_isNaN_4_0
#define uprv_isNegativeInfinity uprv_isNegativeInfinity_4_0
#define uprv_isPositiveInfinity uprv_isPositiveInfinity_4_0
#define uprv_isRuleWhiteSpace uprv_isRuleWhiteSpace_4_0
#define uprv_itou uprv_itou_4_0
#define uprv_log uprv_log_4_0
#define uprv_malloc uprv_malloc_4_0
#define uprv_mapFile uprv_mapFile_4_0
#define uprv_max uprv_max_4_0
#define uprv_maxMantissa uprv_maxMantissa_4_0
#define uprv_maximumPtr uprv_maximumPtr_4_0
#define uprv_min uprv_min_4_0
#define uprv_modf uprv_modf_4_0
#define uprv_openRuleWhiteSpaceSet uprv_openRuleWhiteSpaceSet_4_0
#define uprv_parseCurrency uprv_parseCurrency_4_0
#define uprv_pathIsAbsolute uprv_pathIsAbsolute_4_0
#define uprv_pow uprv_pow_4_0
#define uprv_pow10 uprv_pow10_4_0
#define uprv_realloc uprv_realloc_4_0
#define uprv_round uprv_round_4_0
#define uprv_sortArray uprv_sortArray_4_0
#define uprv_strCompare uprv_strCompare_4_0
#define uprv_strdup uprv_strdup_4_0
#define uprv_strndup uprv_strndup_4_0
#define uprv_syntaxError uprv_syntaxError_4_0
#define uprv_timezone uprv_timezone_4_0
#define uprv_toupper uprv_toupper_4_0
#define uprv_trunc uprv_trunc_4_0
#define uprv_tzname uprv_tzname_4_0
#define uprv_tzset uprv_tzset_4_0
#define uprv_uca_addAnElement uprv_uca_addAnElement_4_0
#define uprv_uca_assembleTable uprv_uca_assembleTable_4_0
#define uprv_uca_canonicalClosure uprv_uca_canonicalClosure_4_0
#define uprv_uca_closeTempTable uprv_uca_closeTempTable_4_0
#define uprv_uca_getCodePointFromRaw uprv_uca_getCodePointFromRaw_4_0
#define uprv_uca_getImplicitFromRaw uprv_uca_getImplicitFromRaw_4_0
#define uprv_uca_getRawFromCodePoint uprv_uca_getRawFromCodePoint_4_0
#define uprv_uca_getRawFromImplicit uprv_uca_getRawFromImplicit_4_0
#define uprv_uca_initImplicitConstants uprv_uca_initImplicitConstants_4_0
#define uprv_uca_initTempTable uprv_uca_initTempTable_4_0
#define uprv_uint16Comparator uprv_uint16Comparator_4_0
#define uprv_uint32Comparator uprv_uint32Comparator_4_0
#define uprv_unmapFile uprv_unmapFile_4_0
#define uregex_appendReplacement uregex_appendReplacement_4_0
#define uregex_appendTail uregex_appendTail_4_0
#define uregex_clone uregex_clone_4_0
#define uregex_close uregex_close_4_0
#define uregex_end uregex_end_4_0
#define uregex_find uregex_find_4_0
#define uregex_findNext uregex_findNext_4_0
#define uregex_flags uregex_flags_4_0
#define uregex_getMatchCallback uregex_getMatchCallback_4_0
#define uregex_getStackLimit uregex_getStackLimit_4_0
#define uregex_getText uregex_getText_4_0
#define uregex_getTimeLimit uregex_getTimeLimit_4_0
#define uregex_group uregex_group_4_0
#define uregex_groupCount uregex_groupCount_4_0
#define uregex_hasAnchoringBounds uregex_hasAnchoringBounds_4_0
#define uregex_hasTransparentBounds uregex_hasTransparentBounds_4_0
#define uregex_hitEnd uregex_hitEnd_4_0
#define uregex_lookingAt uregex_lookingAt_4_0
#define uregex_matches uregex_matches_4_0
#define uregex_open uregex_open_4_0
#define uregex_openC uregex_openC_4_0
#define uregex_pattern uregex_pattern_4_0
#define uregex_regionEnd uregex_regionEnd_4_0
#define uregex_regionStart uregex_regionStart_4_0
#define uregex_replaceAll uregex_replaceAll_4_0
#define uregex_replaceFirst uregex_replaceFirst_4_0
#define uregex_requireEnd uregex_requireEnd_4_0
#define uregex_reset uregex_reset_4_0
#define uregex_setMatchCallback uregex_setMatchCallback_4_0
#define uregex_setRegion uregex_setRegion_4_0
#define uregex_setStackLimit uregex_setStackLimit_4_0
#define uregex_setText uregex_setText_4_0
#define uregex_setTimeLimit uregex_setTimeLimit_4_0
#define uregex_split uregex_split_4_0
#define uregex_start uregex_start_4_0
#define uregex_useAnchoringBounds uregex_useAnchoringBounds_4_0
#define uregex_useTransparentBounds uregex_useTransparentBounds_4_0
#define ures_close ures_close_4_0
#define ures_copyResb ures_copyResb_4_0
#define ures_countArrayItems ures_countArrayItems_4_0
#define ures_findResource ures_findResource_4_0
#define ures_findSubResource ures_findSubResource_4_0
#define ures_getBinary ures_getBinary_4_0
#define ures_getByIndex ures_getByIndex_4_0
#define ures_getByKey ures_getByKey_4_0
#define ures_getByKeyWithFallback ures_getByKeyWithFallback_4_0
#define ures_getFunctionalEquivalent ures_getFunctionalEquivalent_4_0
#define ures_getInt ures_getInt_4_0
#define ures_getIntVector ures_getIntVector_4_0
#define ures_getKey ures_getKey_4_0
#define ures_getKeywordValues ures_getKeywordValues_4_0
#define ures_getLocale ures_getLocale_4_0
#define ures_getLocaleByType ures_getLocaleByType_4_0
#define ures_getName ures_getName_4_0
#define ures_getNextResource ures_getNextResource_4_0
#define ures_getNextString ures_getNextString_4_0
#define ures_getSize ures_getSize_4_0
#define ures_getString ures_getString_4_0
#define ures_getStringByIndex ures_getStringByIndex_4_0
#define ures_getStringByKey ures_getStringByKey_4_0
#define ures_getStringByKeyWithFallback ures_getStringByKeyWithFallback_4_0
#define ures_getType ures_getType_4_0
#define ures_getUInt ures_getUInt_4_0
#define ures_getUTF8String ures_getUTF8String_4_0
#define ures_getUTF8StringByIndex ures_getUTF8StringByIndex_4_0
#define ures_getUTF8StringByKey ures_getUTF8StringByKey_4_0
#define ures_getVersion ures_getVersion_4_0
#define ures_getVersionNumber ures_getVersionNumber_4_0
#define ures_hasNext ures_hasNext_4_0
#define ures_initStackObject ures_initStackObject_4_0
#define ures_open ures_open_4_0
#define ures_openAvailableLocales ures_openAvailableLocales_4_0
#define ures_openDirect ures_openDirect_4_0
#define ures_openFillIn ures_openFillIn_4_0
#define ures_openU ures_openU_4_0
#define ures_resetIterator ures_resetIterator_4_0
#define ures_swap ures_swap_4_0
#define uscript_closeRun uscript_closeRun_4_0
#define uscript_getCode uscript_getCode_4_0
#define uscript_getName uscript_getName_4_0
#define uscript_getScript uscript_getScript_4_0
#define uscript_getShortName uscript_getShortName_4_0
#define uscript_nextRun uscript_nextRun_4_0
#define uscript_openRun uscript_openRun_4_0
#define uscript_resetRun uscript_resetRun_4_0
#define uscript_setRunText uscript_setRunText_4_0
#define usearch_close usearch_close_4_0
#define usearch_first usearch_first_4_0
#define usearch_following usearch_following_4_0
#define usearch_getAttribute usearch_getAttribute_4_0
#define usearch_getBreakIterator usearch_getBreakIterator_4_0
#define usearch_getCollator usearch_getCollator_4_0
#define usearch_getMatchedLength usearch_getMatchedLength_4_0
#define usearch_getMatchedStart usearch_getMatchedStart_4_0
#define usearch_getMatchedText usearch_getMatchedText_4_0
#define usearch_getOffset usearch_getOffset_4_0
#define usearch_getPattern usearch_getPattern_4_0
#define usearch_getText usearch_getText_4_0
#define usearch_handleNextCanonical usearch_handleNextCanonical_4_0
#define usearch_handleNextExact usearch_handleNextExact_4_0
#define usearch_handlePreviousCanonical usearch_handlePreviousCanonical_4_0
#define usearch_handlePreviousExact usearch_handlePreviousExact_4_0
#define usearch_last usearch_last_4_0
#define usearch_next usearch_next_4_0
#define usearch_open usearch_open_4_0
#define usearch_openFromCollator usearch_openFromCollator_4_0
#define usearch_preceding usearch_preceding_4_0
#define usearch_previous usearch_previous_4_0
#define usearch_reset usearch_reset_4_0
#define usearch_search usearch_search_4_0
#define usearch_searchBackwards usearch_searchBackwards_4_0
#define usearch_setAttribute usearch_setAttribute_4_0
#define usearch_setBreakIterator usearch_setBreakIterator_4_0
#define usearch_setCollator usearch_setCollator_4_0
#define usearch_setOffset usearch_setOffset_4_0
#define usearch_setPattern usearch_setPattern_4_0
#define usearch_setText usearch_setText_4_0
#define uset_add uset_add_4_0
#define uset_addAll uset_addAll_4_0
#define uset_addAllCodePoints uset_addAllCodePoints_4_0
#define uset_addRange uset_addRange_4_0
#define uset_addString uset_addString_4_0
#define uset_applyIntPropertyValue uset_applyIntPropertyValue_4_0
#define uset_applyPattern uset_applyPattern_4_0
#define uset_applyPropertyAlias uset_applyPropertyAlias_4_0
#define uset_charAt uset_charAt_4_0
#define uset_clear uset_clear_4_0
#define uset_clone uset_clone_4_0
#define uset_cloneAsThawed uset_cloneAsThawed_4_0
#define uset_close uset_close_4_0
#define uset_compact uset_compact_4_0
#define uset_complement uset_complement_4_0
#define uset_complementAll uset_complementAll_4_0
#define uset_contains uset_contains_4_0
#define uset_containsAll uset_containsAll_4_0
#define uset_containsAllCodePoints uset_containsAllCodePoints_4_0
#define uset_containsNone uset_containsNone_4_0
#define uset_containsRange uset_containsRange_4_0
#define uset_containsSome uset_containsSome_4_0
#define uset_containsString uset_containsString_4_0
#define uset_equals uset_equals_4_0
#define uset_freeze uset_freeze_4_0
#define uset_getItem uset_getItem_4_0
#define uset_getItemCount uset_getItemCount_4_0
#define uset_getSerializedRange uset_getSerializedRange_4_0
#define uset_getSerializedRangeCount uset_getSerializedRangeCount_4_0
#define uset_getSerializedSet uset_getSerializedSet_4_0
#define uset_indexOf uset_indexOf_4_0
#define uset_isEmpty uset_isEmpty_4_0
#define uset_isFrozen uset_isFrozen_4_0
#define uset_open uset_open_4_0
#define uset_openPattern uset_openPattern_4_0
#define uset_openPatternOptions uset_openPatternOptions_4_0
#define uset_remove uset_remove_4_0
#define uset_removeAll uset_removeAll_4_0
#define uset_removeRange uset_removeRange_4_0
#define uset_removeString uset_removeString_4_0
#define uset_resemblesPattern uset_resemblesPattern_4_0
#define uset_retain uset_retain_4_0
#define uset_retainAll uset_retainAll_4_0
#define uset_serialize uset_serialize_4_0
#define uset_serializedContains uset_serializedContains_4_0
#define uset_set uset_set_4_0
#define uset_setSerializedToOne uset_setSerializedToOne_4_0
#define uset_size uset_size_4_0
#define uset_span uset_span_4_0
#define uset_spanBack uset_spanBack_4_0
#define uset_spanBackUTF8 uset_spanBackUTF8_4_0
#define uset_spanUTF8 uset_spanUTF8_4_0
#define uset_toPattern uset_toPattern_4_0
#define usprep_close usprep_close_4_0
#define usprep_open usprep_open_4_0
#define usprep_prepare usprep_prepare_4_0
#define usprep_swap usprep_swap_4_0
#define ustr_foldCase ustr_foldCase_4_0
#define ustr_toLower ustr_toLower_4_0
#define ustr_toTitle ustr_toTitle_4_0
#define ustr_toUpper ustr_toUpper_4_0
#define utext_char32At utext_char32At_4_0
#define utext_clone utext_clone_4_0
#define utext_close utext_close_4_0
#define utext_copy utext_copy_4_0
#define utext_current32 utext_current32_4_0
#define utext_equals utext_equals_4_0
#define utext_extract utext_extract_4_0
#define utext_freeze utext_freeze_4_0
#define utext_getNativeIndex utext_getNativeIndex_4_0
#define utext_getPreviousNativeIndex utext_getPreviousNativeIndex_4_0
#define utext_hasMetaData utext_hasMetaData_4_0
#define utext_isLengthExpensive utext_isLengthExpensive_4_0
#define utext_isWritable utext_isWritable_4_0
#define utext_moveIndex32 utext_moveIndex32_4_0
#define utext_nativeLength utext_nativeLength_4_0
#define utext_next32 utext_next32_4_0
#define utext_next32From utext_next32From_4_0
#define utext_openCharacterIterator utext_openCharacterIterator_4_0
#define utext_openConstUnicodeString utext_openConstUnicodeString_4_0
#define utext_openReplaceable utext_openReplaceable_4_0
#define utext_openUChars utext_openUChars_4_0
#define utext_openUTF8 utext_openUTF8_4_0
#define utext_openUnicodeString utext_openUnicodeString_4_0
#define utext_previous32 utext_previous32_4_0
#define utext_previous32From utext_previous32From_4_0
#define utext_replace utext_replace_4_0
#define utext_setNativeIndex utext_setNativeIndex_4_0
#define utext_setup utext_setup_4_0
#define utf8_appendCharSafeBody utf8_appendCharSafeBody_4_0
#define utf8_back1SafeBody utf8_back1SafeBody_4_0
#define utf8_countTrailBytes utf8_countTrailBytes_4_0
#define utf8_nextCharSafeBody utf8_nextCharSafeBody_4_0
#define utf8_prevCharSafeBody utf8_prevCharSafeBody_4_0
#define utmscale_fromInt64 utmscale_fromInt64_4_0
#define utmscale_getTimeScaleValue utmscale_getTimeScaleValue_4_0
#define utmscale_toInt64 utmscale_toInt64_4_0
#define utrace_cleanup utrace_cleanup_4_0
#define utrace_data utrace_data_4_0
#define utrace_entry utrace_entry_4_0
#define utrace_exit utrace_exit_4_0
#define utrace_format utrace_format_4_0
#define utrace_functionName utrace_functionName_4_0
#define utrace_getFunctions utrace_getFunctions_4_0
#define utrace_getLevel utrace_getLevel_4_0
#define utrace_level utrace_level_4_0
#define utrace_setFunctions utrace_setFunctions_4_0
#define utrace_setLevel utrace_setLevel_4_0
#define utrace_vformat utrace_vformat_4_0
#define utrans_clone utrans_clone_4_0
#define utrans_close utrans_close_4_0
#define utrans_countAvailableIDs utrans_countAvailableIDs_4_0
#define utrans_getAvailableID utrans_getAvailableID_4_0
#define utrans_getID utrans_getID_4_0
#define utrans_getUnicodeID utrans_getUnicodeID_4_0
#define utrans_open utrans_open_4_0
#define utrans_openIDs utrans_openIDs_4_0
#define utrans_openInverse utrans_openInverse_4_0
#define utrans_openU utrans_openU_4_0
#define utrans_register utrans_register_4_0
#define utrans_rep_caseContextIterator utrans_rep_caseContextIterator_4_0
#define utrans_setFilter utrans_setFilter_4_0
#define utrans_stripRules utrans_stripRules_4_0
#define utrans_trans utrans_trans_4_0
#define utrans_transIncremental utrans_transIncremental_4_0
#define utrans_transIncrementalUChars utrans_transIncrementalUChars_4_0
#define utrans_transUChars utrans_transUChars_4_0
#define utrans_unregister utrans_unregister_4_0
#define utrans_unregisterID utrans_unregisterID_4_0
#define utrie_clone utrie_clone_4_0
#define utrie_close utrie_close_4_0
#define utrie_defaultGetFoldingOffset utrie_defaultGetFoldingOffset_4_0
#define utrie_enum utrie_enum_4_0
#define utrie_get32 utrie_get32_4_0
#define utrie_getData utrie_getData_4_0
#define utrie_open utrie_open_4_0
#define utrie_serialize utrie_serialize_4_0
#define utrie_set32 utrie_set32_4_0
#define utrie_setRange32 utrie_setRange32_4_0
#define utrie_swap utrie_swap_4_0
#define utrie_unserialize utrie_unserialize_4_0
#define utrie_unserializeDummy utrie_unserializeDummy_4_0
/* C++ class names renaming defines */

#ifdef XP_CPLUSPLUS
#if !U_HAVE_NAMESPACE

#define AbsoluteValueSubstitution AbsoluteValueSubstitution_4_0
#define AlternateSubstitutionSubtable AlternateSubstitutionSubtable_4_0
#define AnchorTable AnchorTable_4_0
#define AndConstraint AndConstraint_4_0
#define AnnualTimeZoneRule AnnualTimeZoneRule_4_0
#define AnyTransliterator AnyTransliterator_4_0
#define ArabicOpenTypeLayoutEngine ArabicOpenTypeLayoutEngine_4_0
#define ArabicShaping ArabicShaping_4_0
#define BMPSet BMPSet_4_0
#define BasicCalendarFactory BasicCalendarFactory_4_0
#define BasicTimeZone BasicTimeZone_4_0
#define BinarySearchLookupTable BinarySearchLookupTable_4_0
#define BreakIterator BreakIterator_4_0
#define BreakTransliterator BreakTransliterator_4_0
#define BuddhistCalendar BuddhistCalendar_4_0
#define BuildCompactTrieHorizontalNode BuildCompactTrieHorizontalNode_4_0
#define BuildCompactTrieNode BuildCompactTrieNode_4_0
#define BuildCompactTrieVerticalNode BuildCompactTrieVerticalNode_4_0
#define CEBuffer CEBuffer_4_0
#define CECalendar CECalendar_4_0
#define CFactory CFactory_4_0
#define Calendar Calendar_4_0
#define CalendarAstronomer CalendarAstronomer_4_0
#define CalendarCache CalendarCache_4_0
#define CalendarData CalendarData_4_0
#define CalendarService CalendarService_4_0
#define CanonMarkFilter CanonMarkFilter_4_0
#define CanonShaping CanonShaping_4_0
#define CanonicalIterator CanonicalIterator_4_0
#define CaseMapTransliterator CaseMapTransliterator_4_0
#define ChainingContextualSubstitutionFormat1Subtable ChainingContextualSubstitutionFormat1Subtable_4_0
#define ChainingContextualSubstitutionFormat2Subtable ChainingContextualSubstitutionFormat2Subtable_4_0
#define ChainingContextualSubstitutionFormat3Subtable ChainingContextualSubstitutionFormat3Subtable_4_0
#define ChainingContextualSubstitutionSubtable ChainingContextualSubstitutionSubtable_4_0
#define CharSubstitutionFilter CharSubstitutionFilter_4_0
#define CharacterIterator CharacterIterator_4_0
#define CharacterNode CharacterNode_4_0
#define CharsetDetector CharsetDetector_4_0
#define CharsetMatch CharsetMatch_4_0
#define CharsetRecog_2022 CharsetRecog_2022_4_0
#define CharsetRecog_2022CN CharsetRecog_2022CN_4_0
#define CharsetRecog_2022JP CharsetRecog_2022JP_4_0
#define CharsetRecog_2022KR CharsetRecog_2022KR_4_0
#define CharsetRecog_8859_1 CharsetRecog_8859_1_4_0
#define CharsetRecog_8859_1_da CharsetRecog_8859_1_da_4_0
#define CharsetRecog_8859_1_de CharsetRecog_8859_1_de_4_0
#define CharsetRecog_8859_1_en CharsetRecog_8859_1_en_4_0
#define CharsetRecog_8859_1_es CharsetRecog_8859_1_es_4_0
#define CharsetRecog_8859_1_fr CharsetRecog_8859_1_fr_4_0
#define CharsetRecog_8859_1_it CharsetRecog_8859_1_it_4_0
#define CharsetRecog_8859_1_nl CharsetRecog_8859_1_nl_4_0
#define CharsetRecog_8859_1_no CharsetRecog_8859_1_no_4_0
#define CharsetRecog_8859_1_pt CharsetRecog_8859_1_pt_4_0
#define CharsetRecog_8859_1_sv CharsetRecog_8859_1_sv_4_0
#define CharsetRecog_8859_2 CharsetRecog_8859_2_4_0
#define CharsetRecog_8859_2_cs CharsetRecog_8859_2_cs_4_0
#define CharsetRecog_8859_2_hu CharsetRecog_8859_2_hu_4_0
#define CharsetRecog_8859_2_pl CharsetRecog_8859_2_pl_4_0
#define CharsetRecog_8859_2_ro CharsetRecog_8859_2_ro_4_0
#define CharsetRecog_8859_5 CharsetRecog_8859_5_4_0
#define CharsetRecog_8859_5_ru CharsetRecog_8859_5_ru_4_0
#define CharsetRecog_8859_6 CharsetRecog_8859_6_4_0
#define CharsetRecog_8859_6_ar CharsetRecog_8859_6_ar_4_0
#define CharsetRecog_8859_7 CharsetRecog_8859_7_4_0
#define CharsetRecog_8859_7_el CharsetRecog_8859_7_el_4_0
#define CharsetRecog_8859_8 CharsetRecog_8859_8_4_0
#define CharsetRecog_8859_8_I_he CharsetRecog_8859_8_I_he_4_0
#define CharsetRecog_8859_8_he CharsetRecog_8859_8_he_4_0
#define CharsetRecog_8859_9 CharsetRecog_8859_9_4_0
#define CharsetRecog_8859_9_tr CharsetRecog_8859_9_tr_4_0
#define CharsetRecog_KOI8_R CharsetRecog_KOI8_R_4_0
#define CharsetRecog_UTF8 CharsetRecog_UTF8_4_0
#define CharsetRecog_UTF_16_BE CharsetRecog_UTF_16_BE_4_0
#define CharsetRecog_UTF_16_LE CharsetRecog_UTF_16_LE_4_0
#define CharsetRecog_UTF_32 CharsetRecog_UTF_32_4_0
#define CharsetRecog_UTF_32_BE CharsetRecog_UTF_32_BE_4_0
#define CharsetRecog_UTF_32_LE CharsetRecog_UTF_32_LE_4_0
#define CharsetRecog_Unicode CharsetRecog_Unicode_4_0
#define CharsetRecog_big5 CharsetRecog_big5_4_0
#define CharsetRecog_euc CharsetRecog_euc_4_0
#define CharsetRecog_euc_jp CharsetRecog_euc_jp_4_0
#define CharsetRecog_euc_kr CharsetRecog_euc_kr_4_0
#define CharsetRecog_gb_18030 CharsetRecog_gb_18030_4_0
#define CharsetRecog_mbcs CharsetRecog_mbcs_4_0
#define CharsetRecog_sbcs CharsetRecog_sbcs_4_0
#define CharsetRecog_sjis CharsetRecog_sjis_4_0
#define CharsetRecog_windows_1251 CharsetRecog_windows_1251_4_0
#define CharsetRecog_windows_1256 CharsetRecog_windows_1256_4_0
#define CharsetRecognizer CharsetRecognizer_4_0
#define ChineseCalendar ChineseCalendar_4_0
#define ChoiceFormat ChoiceFormat_4_0
#define ClassDefFormat1Table ClassDefFormat1Table_4_0
#define ClassDefFormat2Table ClassDefFormat2Table_4_0
#define ClassDefinitionTable ClassDefinitionTable_4_0
#define CollationElementIterator CollationElementIterator_4_0
#define CollationKey CollationKey_4_0
#define CollationLocaleListEnumeration CollationLocaleListEnumeration_4_0
#define Collator Collator_4_0
#define CollatorFactory CollatorFactory_4_0
#define CompactTrieDictionary CompactTrieDictionary_4_0
#define CompactTrieEnumeration CompactTrieEnumeration_4_0
#define CompoundTransliterator CompoundTransliterator_4_0
#define ContextualGlyphSubstitutionProcessor ContextualGlyphSubstitutionProcessor_4_0
#define ContextualSubstitutionBase ContextualSubstitutionBase_4_0
#define ContextualSubstitutionFormat1Subtable ContextualSubstitutionFormat1Subtable_4_0
#define ContextualSubstitutionFormat2Subtable ContextualSubstitutionFormat2Subtable_4_0
#define ContextualSubstitutionFormat3Subtable ContextualSubstitutionFormat3Subtable_4_0
#define ContextualSubstitutionSubtable ContextualSubstitutionSubtable_4_0
#define CopticCalendar CopticCalendar_4_0
#define CoverageFormat1Table CoverageFormat1Table_4_0
#define CoverageFormat2Table CoverageFormat2Table_4_0
#define CoverageTable CoverageTable_4_0
#define CurrencyAmount CurrencyAmount_4_0
#define CurrencyFormat CurrencyFormat_4_0
#define CurrencyUnit CurrencyUnit_4_0
#define CursiveAttachmentSubtable CursiveAttachmentSubtable_4_0
#define DTRedundantEnumeration DTRedundantEnumeration_4_0
#define DTSkeletonEnumeration DTSkeletonEnumeration_4_0
#define DateFormat DateFormat_4_0
#define DateFormatSymbols DateFormatSymbols_4_0
#define DateInterval DateInterval_4_0
#define DateIntervalFormat DateIntervalFormat_4_0
#define DateIntervalInfo DateIntervalInfo_4_0
#define DateTimeMatcher DateTimeMatcher_4_0
#define DateTimePatternGenerator DateTimePatternGenerator_4_0
#define DateTimeRule DateTimeRule_4_0
#define DecimalFormat DecimalFormat_4_0
#define DecimalFormatSymbols DecimalFormatSymbols_4_0
#define DefaultCalendarFactory DefaultCalendarFactory_4_0
#define DefaultCharMapper DefaultCharMapper_4_0
#define DeviceTable DeviceTable_4_0
#define DictionaryBreakEngine DictionaryBreakEngine_4_0
#define DigitList DigitList_4_0
#define DistanceInfo DistanceInfo_4_0
#define Entry Entry_4_0
#define EnumToOffset EnumToOffset_4_0
#define EscapeTransliterator EscapeTransliterator_4_0
#define EthiopicCalendar EthiopicCalendar_4_0
#define EventListener EventListener_4_0
#define ExtensionSubtable ExtensionSubtable_4_0
#define FeatureListTable FeatureListTable_4_0
#define FieldPosition FieldPosition_4_0
#define FontRuns FontRuns_4_0
#define Format Format_4_0
#define Format1AnchorTable Format1AnchorTable_4_0
#define Format2AnchorTable Format2AnchorTable_4_0
#define Format3AnchorTable Format3AnchorTable_4_0
#define FormatNameEnumeration FormatNameEnumeration_4_0
#define FormatParser FormatParser_4_0
#define Formattable Formattable_4_0
#define ForwardCharacterIterator ForwardCharacterIterator_4_0
#define FractionalPartSubstitution FractionalPartSubstitution_4_0
#define FunctionReplacer FunctionReplacer_4_0
#define GDEFMarkFilter GDEFMarkFilter_4_0
#define GXLayoutEngine GXLayoutEngine_4_0
#define GlyphDefinitionTableHeader GlyphDefinitionTableHeader_4_0
#define GlyphIterator GlyphIterator_4_0
#define GlyphLookupTableHeader GlyphLookupTableHeader_4_0
#define GlyphPositionAdjustments GlyphPositionAdjustments_4_0
#define GlyphPositioningLookupProcessor GlyphPositioningLookupProcessor_4_0
#define GlyphPositioningTableHeader GlyphPositioningTableHeader_4_0
#define GlyphSubstitutionLookupProcessor GlyphSubstitutionLookupProcessor_4_0
#define GlyphSubstitutionTableHeader GlyphSubstitutionTableHeader_4_0
#define Grego Grego_4_0
#define GregorianCalendar GregorianCalendar_4_0
#define HanOpenTypeLayoutEngine HanOpenTypeLayoutEngine_4_0
#define HangulOpenTypeLayoutEngine HangulOpenTypeLayoutEngine_4_0
#define HebrewCalendar HebrewCalendar_4_0
#define ICUBreakIteratorFactory ICUBreakIteratorFactory_4_0
#define ICUBreakIteratorService ICUBreakIteratorService_4_0
#define ICUCollatorFactory ICUCollatorFactory_4_0
#define ICUCollatorService ICUCollatorService_4_0
#define ICULanguageBreakFactory ICULanguageBreakFactory_4_0
#define ICULocaleService ICULocaleService_4_0
#define ICUNotifier ICUNotifier_4_0
#define ICUNumberFormatFactory ICUNumberFormatFactory_4_0
#define ICUNumberFormatService ICUNumberFormatService_4_0
#define ICUResourceBundleFactory ICUResourceBundleFactory_4_0
#define ICUService ICUService_4_0
#define ICUServiceFactory ICUServiceFactory_4_0
#define ICUServiceKey ICUServiceKey_4_0
#define ICU_Utility ICU_Utility_4_0
#define IndianCalendar IndianCalendar_4_0
#define IndicClassTable IndicClassTable_4_0
#define IndicOpenTypeLayoutEngine IndicOpenTypeLayoutEngine_4_0
#define IndicRearrangementProcessor IndicRearrangementProcessor_4_0
#define IndicReordering IndicReordering_4_0
#define InitialTimeZoneRule InitialTimeZoneRule_4_0
#define InputText InputText_4_0
#define IntegralPartSubstitution IntegralPartSubstitution_4_0
#define IslamicCalendar IslamicCalendar_4_0
#define IteratedChar IteratedChar_4_0
#define JapaneseCalendar JapaneseCalendar_4_0
#define KernTable KernTable_4_0
#define KeywordEnumeration KeywordEnumeration_4_0
#define KhmerClassTable KhmerClassTable_4_0
#define KhmerOpenTypeLayoutEngine KhmerOpenTypeLayoutEngine_4_0
#define KhmerReordering KhmerReordering_4_0
#define LECharMapper LECharMapper_4_0
#define LEFontInstance LEFontInstance_4_0
#define LEGlyphFilter LEGlyphFilter_4_0
#define LEGlyphStorage LEGlyphStorage_4_0
#define LEInsertionCallback LEInsertionCallback_4_0
#define LEInsertionList LEInsertionList_4_0
#define LXUtilities LXUtilities_4_0
#define LanguageBreakEngine LanguageBreakEngine_4_0
#define LanguageBreakFactory LanguageBreakFactory_4_0
#define LayoutEngine LayoutEngine_4_0
#define LigatureSubstitutionProcessor LigatureSubstitutionProcessor_4_0
#define LigatureSubstitutionSubtable LigatureSubstitutionSubtable_4_0
#define LocDataParser LocDataParser_4_0
#define Locale Locale_4_0
#define LocaleBased LocaleBased_4_0
#define LocaleKey LocaleKey_4_0
#define LocaleKeyFactory LocaleKeyFactory_4_0
#define LocaleRuns LocaleRuns_4_0
#define LocaleUtility LocaleUtility_4_0
#define LocalizationInfo LocalizationInfo_4_0
#define LookupListTable LookupListTable_4_0
#define LookupProcessor LookupProcessor_4_0
#define LookupSubtable LookupSubtable_4_0
#define LookupTable LookupTable_4_0
#define LowercaseTransliterator LowercaseTransliterator_4_0
#define MPreFixups MPreFixups_4_0
#define MarkArray MarkArray_4_0
#define MarkToBasePositioningSubtable MarkToBasePositioningSubtable_4_0
#define MarkToLigaturePositioningSubtable MarkToLigaturePositioningSubtable_4_0
#define MarkToMarkPositioningSubtable MarkToMarkPositioningSubtable_4_0
#define Math Math_4_0
#define Measure Measure_4_0
#define MeasureFormat MeasureFormat_4_0
#define MeasureUnit MeasureUnit_4_0
#define MessageFormat MessageFormat_4_0
#define MessageFormatAdapter MessageFormatAdapter_4_0
#define ModulusSubstitution ModulusSubstitution_4_0
#define MoonRiseSetCoordFunc MoonRiseSetCoordFunc_4_0
#define MoonTimeAngleFunc MoonTimeAngleFunc_4_0
#define MorphSubtableHeader MorphSubtableHeader_4_0
#define MorphTableHeader MorphTableHeader_4_0
#define MultipleSubstitutionSubtable MultipleSubstitutionSubtable_4_0
#define MultiplierSubstitution MultiplierSubstitution_4_0
#define MutableTrieDictionary MutableTrieDictionary_4_0
#define MutableTrieEnumeration MutableTrieEnumeration_4_0
#define NFFactory NFFactory_4_0
#define NFRule NFRule_4_0
#define NFRuleSet NFRuleSet_4_0
#define NFSubstitution NFSubstitution_4_0
#define NGramParser NGramParser_4_0
#define NameToEnum NameToEnum_4_0
#define NameUnicodeTransliterator NameUnicodeTransliterator_4_0
#define NonContextualGlyphSubstitutionProcessor NonContextualGlyphSubstitutionProcessor_4_0
#define NonContiguousEnumToOffset NonContiguousEnumToOffset_4_0
#define NormalizationTransliterator NormalizationTransliterator_4_0
#define Normalizer Normalizer_4_0
#define NullSubstitution NullSubstitution_4_0
#define NullTransliterator NullTransliterator_4_0
#define NumberFormat NumberFormat_4_0
#define NumberFormatFactory NumberFormatFactory_4_0
#define NumeratorSubstitution NumeratorSubstitution_4_0
#define OlsonTimeZone OlsonTimeZone_4_0
#define OpenTypeLayoutEngine OpenTypeLayoutEngine_4_0
#define OpenTypeUtilities OpenTypeUtilities_4_0
#define OrConstraint OrConstraint_4_0
#define PCEBuffer PCEBuffer_4_0
#define PairPositioningFormat1Subtable PairPositioningFormat1Subtable_4_0
#define PairPositioningFormat2Subtable PairPositioningFormat2Subtable_4_0
#define PairPositioningSubtable PairPositioningSubtable_4_0
#define ParagraphLayout ParagraphLayout_4_0
#define ParseData ParseData_4_0
#define ParsePosition ParsePosition_4_0
#define PatternMap PatternMap_4_0
#define PatternMapIterator PatternMapIterator_4_0
#define PersianCalendar PersianCalendar_4_0
#define PluralFormat PluralFormat_4_0
#define PluralKeywordEnumeration PluralKeywordEnumeration_4_0
#define PluralRules PluralRules_4_0
#define PropertyAliases PropertyAliases_4_0
#define PtnElem PtnElem_4_0
#define PtnSkeleton PtnSkeleton_4_0
#define Quantifier Quantifier_4_0
#define RBBIDataWrapper RBBIDataWrapper_4_0
#define RBBINode RBBINode_4_0
#define RBBIRuleBuilder RBBIRuleBuilder_4_0
#define RBBIRuleScanner RBBIRuleScanner_4_0
#define RBBISetBuilder RBBISetBuilder_4_0
#define RBBIStateDescriptor RBBIStateDescriptor_4_0
#define RBBISymbolTable RBBISymbolTable_4_0
#define RBBISymbolTableEntry RBBISymbolTableEntry_4_0
#define RBBITableBuilder RBBITableBuilder_4_0
#define RCEBuffer RCEBuffer_4_0
#define RangeDescriptor RangeDescriptor_4_0
#define RegexCImpl RegexCImpl_4_0
#define RegexCompile RegexCompile_4_0
#define RegexMatcher RegexMatcher_4_0
#define RegexPattern RegexPattern_4_0
#define RegexStaticSets RegexStaticSets_4_0
#define RelativeDateFormat RelativeDateFormat_4_0
#define RemoveTransliterator RemoveTransliterator_4_0
#define Replaceable Replaceable_4_0
#define ReplaceableGlue ReplaceableGlue_4_0
#define ResourceBundle ResourceBundle_4_0
#define RiseSetCoordFunc RiseSetCoordFunc_4_0
#define RuleBasedBreakIterator RuleBasedBreakIterator_4_0
#define RuleBasedCollator RuleBasedCollator_4_0
#define RuleBasedNumberFormat RuleBasedNumberFormat_4_0
#define RuleBasedTimeZone RuleBasedTimeZone_4_0
#define RuleBasedTransliterator RuleBasedTransliterator_4_0
#define RuleChain RuleChain_4_0
#define RuleCharacterIterator RuleCharacterIterator_4_0
#define RuleHalf RuleHalf_4_0
#define RuleParser RuleParser_4_0
#define RunArray RunArray_4_0
#define SafeZoneStringFormatPtr SafeZoneStringFormatPtr_4_0
#define SameValueSubstitution SameValueSubstitution_4_0
#define ScriptListTable ScriptListTable_4_0
#define ScriptRunIterator ScriptRunIterator_4_0
#define ScriptTable ScriptTable_4_0
#define SearchIterator SearchIterator_4_0
#define SegmentArrayProcessor SegmentArrayProcessor_4_0
#define SegmentSingleProcessor SegmentSingleProcessor_4_0
#define ServiceEnumeration ServiceEnumeration_4_0
#define ServiceListener ServiceListener_4_0
#define SimpleArrayProcessor SimpleArrayProcessor_4_0
#define SimpleDateFormat SimpleDateFormat_4_0
#define SimpleFactory SimpleFactory_4_0
#define SimpleLocaleKeyFactory SimpleLocaleKeyFactory_4_0
#define SimpleNumberFormatFactory SimpleNumberFormatFactory_4_0
#define SimpleTimeZone SimpleTimeZone_4_0
#define SinglePositioningFormat1Subtable SinglePositioningFormat1Subtable_4_0
#define SinglePositioningFormat2Subtable SinglePositioningFormat2Subtable_4_0
#define SinglePositioningSubtable SinglePositioningSubtable_4_0
#define SingleSubstitutionFormat1Subtable SingleSubstitutionFormat1Subtable_4_0
#define SingleSubstitutionFormat2Subtable SingleSubstitutionFormat2Subtable_4_0
#define SingleSubstitutionSubtable SingleSubstitutionSubtable_4_0
#define SingleTableProcessor SingleTableProcessor_4_0
#define Spec Spec_4_0
#define StateTableProcessor StateTableProcessor_4_0
#define StringCharacterIterator StringCharacterIterator_4_0
#define StringEnumeration StringEnumeration_4_0
#define StringLocalizationInfo StringLocalizationInfo_4_0
#define StringMatcher StringMatcher_4_0
#define StringPair StringPair_4_0
#define StringReplacer StringReplacer_4_0
#define StringSearch StringSearch_4_0
#define StyleRuns StyleRuns_4_0
#define SubstitutionLookup SubstitutionLookup_4_0
#define SubtableProcessor SubtableProcessor_4_0
#define SunTimeAngleFunc SunTimeAngleFunc_4_0
#define SymbolTable SymbolTable_4_0
#define TZEnumeration TZEnumeration_4_0
#define TaiwanCalendar TaiwanCalendar_4_0
#define TernaryNode TernaryNode_4_0
#define TextTrieMap TextTrieMap_4_0
#define TextTrieMapSearchResultHandler TextTrieMapSearchResultHandler_4_0
#define ThaiBreakEngine ThaiBreakEngine_4_0
#define ThaiLayoutEngine ThaiLayoutEngine_4_0
#define ThaiShaping ThaiShaping_4_0
#define TibetanClassTable TibetanClassTable_4_0
#define TibetanOpenTypeLayoutEngine TibetanOpenTypeLayoutEngine_4_0
#define TibetanReordering TibetanReordering_4_0
#define TimeArrayTimeZoneRule TimeArrayTimeZoneRule_4_0
#define TimeZone TimeZone_4_0
#define TimeZoneRule TimeZoneRule_4_0
#define TimeZoneTransition TimeZoneTransition_4_0
#define TitlecaseTransliterator TitlecaseTransliterator_4_0
#define TransliterationRule TransliterationRule_4_0
#define TransliterationRuleData TransliterationRuleData_4_0
#define TransliterationRuleSet TransliterationRuleSet_4_0
#define Transliterator Transliterator_4_0
#define TransliteratorAlias TransliteratorAlias_4_0
#define TransliteratorIDParser TransliteratorIDParser_4_0
#define TransliteratorParser TransliteratorParser_4_0
#define TransliteratorRegistry TransliteratorRegistry_4_0
#define TrieWordDictionary TrieWordDictionary_4_0
#define TrimmedArrayProcessor TrimmedArrayProcessor_4_0
#define UCharCharacterIterator UCharCharacterIterator_4_0
#define UCollationPCE UCollationPCE_4_0
#define ULocRuns ULocRuns_4_0
#define UMemory UMemory_4_0
#define UObject UObject_4_0
#define URegularExpression URegularExpression_4_0
#define UStack UStack_4_0
#define UStringEnumeration UStringEnumeration_4_0
#define UVector UVector_4_0
#define UVector32 UVector32_4_0
#define UnescapeTransliterator UnescapeTransliterator_4_0
#define UnhandledEngine UnhandledEngine_4_0
#define UnicodeArabicOpenTypeLayoutEngine UnicodeArabicOpenTypeLayoutEngine_4_0
#define UnicodeFilter UnicodeFilter_4_0
#define UnicodeFunctor UnicodeFunctor_4_0
#define UnicodeMatcher UnicodeMatcher_4_0
#define UnicodeNameTransliterator UnicodeNameTransliterator_4_0
#define UnicodeReplacer UnicodeReplacer_4_0
#define UnicodeSet UnicodeSet_4_0
#define UnicodeSetIterator UnicodeSetIterator_4_0
#define UnicodeSetStringSpan UnicodeSetStringSpan_4_0
#define UnicodeString UnicodeString_4_0
#define UppercaseTransliterator UppercaseTransliterator_4_0
#define VTZReader VTZReader_4_0
#define VTZWriter VTZWriter_4_0
#define VTimeZone VTimeZone_4_0
#define ValueRecord ValueRecord_4_0
#define ValueRuns ValueRuns_4_0
#define ZSFCache ZSFCache_4_0
#define ZSFCacheEntry ZSFCacheEntry_4_0
#define ZoneMeta ZoneMeta_4_0
#define ZoneStringFormat ZoneStringFormat_4_0
#define ZoneStringInfo ZoneStringInfo_4_0
#define ZoneStringSearchResultHandler ZoneStringSearchResultHandler_4_0
#define ZoneStrings ZoneStrings_4_0
#define locale_set_default_internal locale_set_default_internal_4_0
#define util64_fromDouble util64_fromDouble_4_0
#define util64_pow util64_pow_4_0
#define util64_tou util64_tou_4_0

#endif
#endif

#endif

#endif
