( cd usr/lib/icu ; rm -rf current )
( cd usr/lib/icu ; ln -sf 4.0 current )
( cd usr/lib/icu ; rm -rf Makefile.inc )
( cd usr/lib/icu ; ln -sf current/Makefile.inc Makefile.inc )
( cd usr/lib ; rm -rf libicuio.so )
( cd usr/lib ; ln -sf libicuio.so.40.0 libicuio.so )
( cd usr/lib ; rm -rf libicule.so )
( cd usr/lib ; ln -sf libicule.so.40.0 libicule.so )
( cd usr/lib ; rm -rf libiculx.so )
( cd usr/lib ; ln -sf libiculx.so.40.0 libiculx.so )
( cd usr/lib ; rm -rf libicuuc.so )
( cd usr/lib ; ln -sf libicuuc.so.40.0 libicuuc.so )
( cd usr/lib ; rm -rf libicutu.so )
( cd usr/lib ; ln -sf libicutu.so.40.0 libicutu.so )
( cd usr/lib ; rm -rf libicudata.so.40 )
( cd usr/lib ; ln -sf libicudata.so.40.0 libicudata.so.40 )
( cd usr/lib ; rm -rf libicuio.so.40 )
( cd usr/lib ; ln -sf libicuio.so.40.0 libicuio.so.40 )
( cd usr/lib ; rm -rf libicudata.so )
( cd usr/lib ; ln -sf libicudata.so.40.0 libicudata.so )
( cd usr/lib ; rm -rf libicui18n.so )
( cd usr/lib ; ln -sf libicui18n.so.40.0 libicui18n.so )
( cd usr/lib ; rm -rf libiculx.so.40 )
( cd usr/lib ; ln -sf libiculx.so.40.0 libiculx.so.40 )
( cd usr/lib ; rm -rf libicui18n.so.40 )
( cd usr/lib ; ln -sf libicui18n.so.40.0 libicui18n.so.40 )
( cd usr/lib ; rm -rf libicule.so.40 )
( cd usr/lib ; ln -sf libicule.so.40.0 libicule.so.40 )
( cd usr/lib ; rm -rf libicuuc.so.40 )
( cd usr/lib ; ln -sf libicuuc.so.40.0 libicuuc.so.40 )
( cd usr/lib ; rm -rf libicutu.so.40 )
( cd usr/lib ; ln -sf libicutu.so.40.0 libicutu.so.40 )
